import { Client, GraphQLRequestParams } from '@urql/core';
export { gql } from '@urql/core';
import * as _urql_core_dist_urql_core_chunk from '@urql/core/dist/urql-core-chunk';

type Maybe<T> = T | null;
type InputMaybe<T> = Maybe<T>;
type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
/** All built-in and custom scalars, mapped to their actual values */
type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    BigInt: any;
    DateTime: any;
    JSON: any;
    JSONObject: any;
};
type CodegenContractStandard = 'ERC20' | 'ERC721' | 'ERC1155';
type CodegenContractStandardInput = {
    eq?: InputMaybe<CodegenContractStandard>;
    in?: InputMaybe<Array<CodegenContractStandard>>;
    notIn?: InputMaybe<Array<CodegenContractStandard>>;
};
type CodegenDateTimeInput = {
    eq?: InputMaybe<Scalars['DateTime']>;
    gt?: InputMaybe<Scalars['DateTime']>;
    gte?: InputMaybe<Scalars['DateTime']>;
    lt?: InputMaybe<Scalars['DateTime']>;
    lte?: InputMaybe<Scalars['DateTime']>;
};
/** Gas Prices for a given block. Gas values are returned in Wei. */
type CodegenGasPrice = {
    __typename?: 'GasPrice';
    average: Scalars['Float'];
    blockNumber: Scalars['Int'];
    ceiling: Scalars['Float'];
    floor: Scalars['Float'];
    median: Scalars['Float'];
    total: Scalars['Float'];
};
/** Filter input for gas prices */
type CodegenGasPriceFilterInput = {
    blockNumber?: InputMaybe<CodegenIntegerInput>;
};
type CodegenIntegerInput = {
    eq?: InputMaybe<Scalars['Int']>;
    gt?: InputMaybe<Scalars['Int']>;
    gte?: InputMaybe<Scalars['Int']>;
    in?: InputMaybe<Array<Scalars['Int']>>;
    lt?: InputMaybe<Scalars['Int']>;
    lte?: InputMaybe<Scalars['Int']>;
};
/** Marketplace where the token was sold */
type CodegenMarketplace = 'BLUR' | 'CRYPTOPUNKS' | 'LOOKSRARE' | 'NIFTY_GATEWAY' | 'OPENSEA' | 'SEAPORT' | 'X2Y2' | 'ZEROX';
type CodegenMarketplaceInput = {
    eq?: InputMaybe<CodegenMarketplace>;
    in?: InputMaybe<Array<CodegenMarketplace>>;
    notIn?: InputMaybe<Array<CodegenMarketplace>>;
};
type CodegenStringInput = {
    eq?: InputMaybe<Scalars['String']>;
    in?: InputMaybe<Array<Scalars['String']>>;
    notIn?: InputMaybe<Array<Scalars['String']>>;
};
/** Filter input for token events */
type CodegenTokenEventsFilterInput = {
    /** Filter token events by their block number */
    blockNumber?: InputMaybe<CodegenIntegerInput>;
    /** Filter token events by contract address */
    contractAddress?: InputMaybe<CodegenStringInput>;
    /** Filter token events by their contract standard */
    contractStandard?: InputMaybe<CodegenContractStandardInput>;
    /** Filter token events by the "from" wallet */
    fromAddress?: InputMaybe<CodegenStringInput>;
    /** Filter token events by the marketplace. It's only valid for SALE types */
    marketplace?: InputMaybe<CodegenMarketplaceInput>;
    /** Filter token events by their estimated confirmation date */
    timestamp?: InputMaybe<CodegenDateTimeInput>;
    /** Filter token events by the "to" wallet */
    toAddress?: InputMaybe<CodegenStringInput>;
    /** Filter token events by transaction hash */
    transactionHash?: InputMaybe<CodegenStringInput>;
    /** Filter token events by their type */
    type?: InputMaybe<CodegenTokenTransferTypeInput>;
    /** Filter token events by the "to" and "from" wallet */
    walletAddress?: InputMaybe<CodegenStringInput>;
};
type CodegenTokenTransferType = 'BURN' | 'MINT' | 'SALE' | 'SWAP' | 'TRANSFER';
type CodegenTokenTransferTypeInput = {
    eq?: InputMaybe<CodegenTokenTransferType>;
    in?: InputMaybe<Array<CodegenTokenTransferType>>;
    notIn?: InputMaybe<Array<CodegenTokenTransferType>>;
};
/** Filter input for transactions */
type CodegenTransactionsFilterInput = {
    blockNumber?: InputMaybe<CodegenIntegerInput>;
    fromAddress?: InputMaybe<Scalars['String']>;
    timestamp?: InputMaybe<CodegenDateTimeInput>;
    toAddress?: InputMaybe<Scalars['String']>;
};
/** Filter of nfts in a wallet */
type CodegenWalletNFTsFilterInput = {
    contractAddressIn?: InputMaybe<Array<Scalars['String']>>;
};
type CodegenEthMainnetContractDetailsQueryVariables = Exact<{
    contractAddress: Scalars['String'];
}>;
type CodegenEthereumMainnetEventsGetAllQueryVariables = Exact<{
    filter?: InputMaybe<CodegenTokenEventsFilterInput>;
    after?: InputMaybe<Scalars['String']>;
    first?: InputMaybe<Scalars['Int']>;
}>;
type CodegenEthereumMainnetEventsByContractQueryVariables = Exact<{
    contractAddress: Scalars['String'];
    filter?: InputMaybe<CodegenTokenEventsFilterInput>;
    after?: InputMaybe<Scalars['String']>;
    first?: InputMaybe<Scalars['Int']>;
}>;
type CodegenEthMainnetEventsByCollectionQueryVariables = Exact<{
    contractAddress: Scalars['String'];
    filter?: InputMaybe<CodegenTokenEventsFilterInput>;
    after?: InputMaybe<Scalars['String']>;
    first?: InputMaybe<Scalars['Int']>;
}>;
type CodegenEthereumMainnetEventsByNftQueryVariables = Exact<{
    contractAddress: Scalars['String'];
    tokenId: Scalars['String'];
    filter?: InputMaybe<CodegenTokenEventsFilterInput>;
    after?: InputMaybe<Scalars['String']>;
    first?: InputMaybe<Scalars['Int']>;
}>;
type CodegenEthMainnetWalletNFTsByContractAddressQueryVariables = Exact<{
    contractAddress: Scalars['String'];
    after?: InputMaybe<Scalars['String']>;
    first?: InputMaybe<Scalars['Int']>;
}>;
type CodegenEthMainnetWalletNFTsByAddressQueryVariables = Exact<{
    address: Scalars['String'];
    after?: InputMaybe<Scalars['String']>;
    first?: InputMaybe<Scalars['Int']>;
    filter?: InputMaybe<CodegenWalletNFTsFilterInput>;
}>;
type CodegenEthMainnetWalletNFTsByEnsQueryVariables = Exact<{
    ensName: Scalars['String'];
    after?: InputMaybe<Scalars['String']>;
    first?: InputMaybe<Scalars['Int']>;
    filter?: InputMaybe<CodegenWalletNFTsFilterInput>;
}>;
type CodegenEthMainnetNFTDetailsQueryVariables = Exact<{
    contractAddress: Scalars['String'];
    tokenId: Scalars['String'];
}>;
type CodegenEthMainnetNftCollectionDetailsQueryVariables = Exact<{
    contractAddress: Scalars['String'];
}>;
type CodegenEthMainnetTrendingCollectionsQueryVariables = Exact<{
    first?: InputMaybe<Scalars['Int']>;
    after?: InputMaybe<Scalars['String']>;
}>;
type CodegenEthMainnetBalancesByWalletAddressQueryVariables = Exact<{
    address: Scalars['String'];
    first?: InputMaybe<Scalars['Int']>;
    after?: InputMaybe<Scalars['String']>;
}>;
type CodegenEthMainnetBalancesByWalletENSQueryVariables = Exact<{
    ensName: Scalars['String'];
    first?: InputMaybe<Scalars['Int']>;
    after?: InputMaybe<Scalars['String']>;
}>;
type CodegenEthMainnetTransactionsByHashQueryVariables = Exact<{
    hash: Scalars['String'];
}>;
type CodegenEthMainnetTransactionsBySearchQueryVariables = Exact<{
    filter: CodegenTransactionsFilterInput;
    first?: InputMaybe<Scalars['Int']>;
    after?: InputMaybe<Scalars['String']>;
}>;
type CodegenEthMainnetTransactionsByWalletAddressQueryVariables = Exact<{
    address: Scalars['String'];
    first?: InputMaybe<Scalars['Int']>;
    after?: InputMaybe<Scalars['String']>;
}>;
type CodegenEthMainnetTransactionsByWalletENSQueryVariables = Exact<{
    ensName: Scalars['String'];
    first?: InputMaybe<Scalars['Int']>;
    after?: InputMaybe<Scalars['String']>;
}>;
type CodegenEthMainnetGasPricesQueryVariables = Exact<{
    filter?: InputMaybe<CodegenGasPriceFilterInput>;
}>;
type CodegenNftCollectionInfoFragment = {
    __typename?: 'EVMSchemaType';
    collection?: {
        __typename?: 'ERC721Collection';
        address: string;
        baseTokenUri?: string | null;
        circulatingSupply?: any | null;
        description?: string | null;
        externalUrl?: string | null;
        name?: string | null;
        slug?: string | null;
        symbol?: string | null;
        totalSupply?: any | null;
        twitterUsername?: string | null;
        bannerImage?: Array<{
            __typename?: 'TokenUpload';
            height?: number | null;
            mimeType?: string | null;
            url: string;
            width?: number | null;
        }> | null;
        contract?: {
            __typename?: 'NFTContract';
            address: string;
            isVerified?: boolean | null;
            name?: string | null;
            symbol?: string | null;
            supportedErcInterfaces?: Array<string> | null;
        } | null;
        image?: Array<{
            __typename?: 'TokenUpload';
            height?: number | null;
            mimeType?: string | null;
            url: string;
            width?: number | null;
        }> | null;
        ohlcvChart?: Array<{
            __typename?: 'CollectionOHLCVChart';
            average?: number | null;
            close?: number | null;
            count: number;
            high?: number | null;
            low?: number | null;
            open?: number | null;
            volume?: number | null;
            timestamp: any;
        }> | null;
        openseaMetadata?: {
            __typename?: 'OpenSeaMetadata';
            isHidden?: boolean | null;
            isVerified?: boolean | null;
            unsafeSlug?: string | null;
        } | null;
    } | {
        __typename?: 'ERC1155Collection';
        address: string;
        baseTokenUri?: string | null;
        circulatingSupply?: any | null;
        description?: string | null;
        externalUrl?: string | null;
        name?: string | null;
        slug?: string | null;
        symbol?: string | null;
        totalSupply?: any | null;
        twitterUsername?: string | null;
        bannerImage?: Array<{
            __typename?: 'TokenUpload';
            height?: number | null;
            mimeType?: string | null;
            url: string;
            width?: number | null;
        }> | null;
        contract?: {
            __typename?: 'NFTContract';
            address: string;
            isVerified?: boolean | null;
            name?: string | null;
            symbol?: string | null;
            supportedErcInterfaces?: Array<string> | null;
        } | null;
        image?: Array<{
            __typename?: 'TokenUpload';
            height?: number | null;
            mimeType?: string | null;
            url: string;
            width?: number | null;
        }> | null;
        ohlcvChart?: Array<{
            __typename?: 'CollectionOHLCVChart';
            average?: number | null;
            close?: number | null;
            count: number;
            high?: number | null;
            low?: number | null;
            open?: number | null;
            volume?: number | null;
            timestamp: any;
        }> | null;
        openseaMetadata?: {
            __typename?: 'OpenSeaMetadata';
            isHidden?: boolean | null;
            isVerified?: boolean | null;
            unsafeSlug?: string | null;
        } | null;
    } | null;
};
type CodegenNftDetailsFragment = {
    __typename?: 'EVMSchemaType';
    nft?: {
        __typename?: 'ERC721NFT';
        animationUrl?: string | null;
        collectionSlug?: string | null;
        contractAddress: string;
        description?: string | null;
        externalUrl?: string | null;
        metadata?: any | null;
        name?: string | null;
        tokenId: any;
        wallet?: {
            __typename?: 'Wallet';
            address: string;
            ensName?: string | null;
        } | null;
    } | {
        __typename?: 'ERC1155NFT';
        animationUrl?: string | null;
        collectionSlug?: string | null;
        contractAddress: string;
        description?: string | null;
        externalUrl?: string | null;
        metadata?: any | null;
        name?: string | null;
        tokenId: any;
        wallets: {
            __typename?: 'ERC1155NFTWalletsConnection';
            edges: Array<{
                __typename?: 'ERC1155NFTWalletsConnectionEdge';
                node: {
                    __typename?: 'Wallet';
                    address: string;
                    ensName?: string | null;
                };
            }>;
        };
    } | null;
};
type CodegenERC1155NFTNodeFragment = {
    __typename?: 'ERC1155NFT';
    animationUrl?: string | null;
    collectionSlug?: string | null;
    contractAddress: string;
    description?: string | null;
    externalUrl?: string | null;
    metadata?: any | null;
    name?: string | null;
    tokenId: any;
    wallets: {
        __typename?: 'ERC1155NFTWalletsConnection';
        edges: Array<{
            __typename?: 'ERC1155NFTWalletsConnectionEdge';
            node: {
                __typename?: 'Wallet';
                address: string;
                ensName?: string | null;
            };
        }>;
    };
};
type CodegenERC721NFTNodeFragment = {
    __typename?: 'ERC721NFT';
    animationUrl?: string | null;
    collectionSlug?: string | null;
    contractAddress: string;
    description?: string | null;
    externalUrl?: string | null;
    metadata?: any | null;
    name?: string | null;
    tokenId: any;
    attributes?: Array<{
        __typename?: 'TokenAttribute';
        name: string;
        value: string;
    }> | null;
    wallet?: {
        __typename?: 'Wallet';
        address: string;
        ensName?: string | null;
    } | null;
};
type CodegenTransactionsNodeFragment = {
    __typename?: 'Transaction';
    blockNumber: number;
    blockTimestamp: any;
    contractAddress?: string | null;
    fromAddress: string;
    cumulativeGasUsed: any;
    effectiveGasPrice?: any | null;
    gas?: any | null;
    gasPrice?: any | null;
    gasUsed: any;
    hash: string;
    maxFeePerGas?: any | null;
    maxPriorityFeePerGas?: any | null;
    toAddress?: string | null;
    type?: string | null;
    input?: string | null;
    transactionIndex: number;
    value?: any | null;
};
type CodegenTrendingCollectionInfo_CodegenERC721Collection_CodegenFragment = {
    __typename?: 'ERC721Collection';
    address: string;
    baseTokenUri?: string | null;
    circulatingSupply?: any | null;
    description?: string | null;
    externalUrl?: string | null;
    name?: string | null;
    symbol?: string | null;
    totalSupply?: any | null;
    twitterUsername?: string | null;
    image?: Array<{
        __typename?: 'TokenUpload';
        height?: number | null;
        mimeType?: string | null;
        url: string;
        width?: number | null;
    }> | null;
    openseaMetadata?: {
        __typename?: 'OpenSeaMetadata';
        isHidden?: boolean | null;
        isVerified?: boolean | null;
        unsafeSlug?: string | null;
    } | null;
};
type CodegenTrendingCollectionInfo_CodegenERC1155Collection_CodegenFragment = {
    __typename?: 'ERC1155Collection';
    address: string;
    baseTokenUri?: string | null;
    circulatingSupply?: any | null;
    description?: string | null;
    externalUrl?: string | null;
    name?: string | null;
    symbol?: string | null;
    totalSupply?: any | null;
    twitterUsername?: string | null;
    image?: Array<{
        __typename?: 'TokenUpload';
        height?: number | null;
        mimeType?: string | null;
        url: string;
        width?: number | null;
    }> | null;
    openseaMetadata?: {
        __typename?: 'OpenSeaMetadata';
        isHidden?: boolean | null;
        isVerified?: boolean | null;
        unsafeSlug?: string | null;
    } | null;
};
type CodegenTrendingCollectionInfoFragment = CodegenTrendingCollectionInfo_CodegenERC721Collection_CodegenFragment | CodegenTrendingCollectionInfo_CodegenERC1155Collection_CodegenFragment;
type CodegenWalletNFTNodeFragment = {
    __typename?: 'WalletNFT';
    nft?: {
        __typename?: 'ERC721NFT';
        animationUrl?: string | null;
        collectionSlug?: string | null;
        contractAddress: string;
        description?: string | null;
        externalUrl?: string | null;
        metadata?: any | null;
        name?: string | null;
        tokenId: any;
    } | {
        __typename?: 'ERC1155NFT';
        animationUrl?: string | null;
        collectionSlug?: string | null;
        contractAddress: string;
        description?: string | null;
        externalUrl?: string | null;
        metadata?: any | null;
        name?: string | null;
        tokenId: any;
    } | null;
};
type CodegenContractInfo_CodegenNFTContract_CodegenFragment = {
    __typename?: 'NFTContract';
    abi?: any | null;
    address: string;
    isVerified?: boolean | null;
    name?: string | null;
    supportedErcInterfaces?: Array<string> | null;
    symbol?: string | null;
};
type CodegenContractInfo_CodegenTokenContract_CodegenFragment = {
    __typename?: 'TokenContract';
    decimals?: any | null;
    abi?: any | null;
    address: string;
    isVerified?: boolean | null;
    name?: string | null;
    supportedErcInterfaces?: Array<string> | null;
    symbol?: string | null;
};
type CodegenContractInfoFragment = CodegenContractInfo_CodegenNFTContract_CodegenFragment | CodegenContractInfo_CodegenTokenContract_CodegenFragment;
type CodegenTokenBalanceNodeFragment = {
    __typename?: 'WalletTokenBalance';
    totalBalance: any;
    contract?: {
        __typename?: 'TokenContract';
        address: string;
        decimals?: any | null;
        name?: string | null;
        symbol?: string | null;
    } | null;
};
type CodegenTokenEventInfo_CodegenTokenBurnEvent_CodegenFragment = {
    __typename?: 'TokenBurnEvent';
    tokenId?: any | null;
    tokenQuantity: any;
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfo_CodegenTokenMintEvent_CodegenFragment = {
    __typename?: 'TokenMintEvent';
    tokenQuantity: any;
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfo_CodegenTokenSaleEvent_CodegenFragment = {
    __typename?: 'TokenSaleEvent';
    marketplace?: CodegenMarketplace | null;
    receivedTokenContractAddress?: string | null;
    receivedTokenId?: any | null;
    sentTokenId?: any | null;
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfo_CodegenTokenSwapEvent_CodegenFragment = {
    __typename?: 'TokenSwapEvent';
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfo_CodegenTokenTransferEvent_CodegenFragment = {
    __typename?: 'TokenTransferEvent';
    tokenId?: any | null;
    contractAddress: string;
    tokenQuantity: any;
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfoFragment = CodegenTokenEventInfo_CodegenTokenBurnEvent_CodegenFragment | CodegenTokenEventInfo_CodegenTokenMintEvent_CodegenFragment | CodegenTokenEventInfo_CodegenTokenSaleEvent_CodegenFragment | CodegenTokenEventInfo_CodegenTokenSwapEvent_CodegenFragment | CodegenTokenEventInfo_CodegenTokenTransferEvent_CodegenFragment;
type CodegenPaginationFragment = {
    __typename?: 'PageInfo';
    endCursor?: string | null;
    hasNextPage: boolean;
    hasPreviousPage: boolean;
    startCursor?: string | null;
};

type ResultOutput = Record<string | number | symbol, any>;

interface InternalOptions {
    keepTypename?: boolean;
}
declare class CustomUrqlClient {
    urqlClient: Client;
    constructor(urqlClient: Client);
    query<TVariables extends Record<string, any>, KResults extends Record<string, any>, KResultsOutput extends ResultOutput>(options: GraphQLRequestParams<any, TVariables> & InternalOptions): Promise<{
        data: any;
        operation: _urql_core_dist_urql_core_chunk.Operation<any, Record<string, any> | TVariables>;
        error?: _urql_core_dist_urql_core_chunk.CombinedError | undefined;
        extensions?: Record<string, any> | undefined;
        stale: boolean;
        hasNext: boolean;
    }>;
}

type ChainName = 'ethereum' | 'polygon' | 'ethereumSepolia';

type NonQueryInput = {
    chain?: ChainName;
};

type WalletNFTsByAddressQueryVariables = CodegenEthMainnetWalletNFTsByAddressQueryVariables;
type WalletNFTsByAddressInput = WalletNFTsByAddressQueryVariables & NonQueryInput;
type WalletNFTsByAddressResult = {
    address: string;
    ensName: string;
    results: CodegenWalletNFTNodeFragment['nft'][];
    pageInfo: CodegenPaginationFragment;
};

type NFTDetailsQueryVariables = CodegenEthMainnetNFTDetailsQueryVariables;
type NFTDetailsInput = NFTDetailsQueryVariables & NonQueryInput;
type NFTDetailsResult = {
    nft: CodegenNftDetailsFragment['nft'];
};

type NftCollectionDetailsQueryVariables = CodegenEthMainnetNftCollectionDetailsQueryVariables;
type NftCollectionDetailsInput = NftCollectionDetailsQueryVariables & NonQueryInput;
type NftCollectionDetailsResult = {
    collection: CodegenNftCollectionInfoFragment['collection'];
};

type NFTTrendingCollectionsQueryVariables = CodegenEthMainnetTrendingCollectionsQueryVariables;
type NFTTrendingCollectionsInput = NFTTrendingCollectionsQueryVariables & NonQueryInput;
type NFTTrendingCollectionResult = {
    results: CodegenTrendingCollectionInfoFragment[];
    pageInfo: CodegenPaginationFragment;
};

type NftErcStandards = 'ERC721' | 'ERC1155';

type NFTsByContractAddressQueryVariables = CodegenEthMainnetWalletNFTsByContractAddressQueryVariables;
type NFTsByContractAddressInput = NFTsByContractAddressQueryVariables & NonQueryInput;
type NFTsByContractAddressResult = {
    standard: NftErcStandards | null;
    results: [CodegenERC721NFTNodeFragment | CodegenERC1155NFTNodeFragment][];
    pageInfo: CodegenPaginationFragment;
};

declare class NftsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getByWallet(variables: WalletNFTsByAddressInput): Promise<WalletNFTsByAddressResult>;
    private getByWalletENS;
    private getByWalletAddress;
    getTrendingCollections(variables: NFTTrendingCollectionsInput): Promise<NFTTrendingCollectionResult>;
    getByContractAddress(variables: NFTsByContractAddressInput): Promise<NFTsByContractAddressResult>;
    getNFTDetails(variables: NFTDetailsInput): Promise<NFTDetailsResult>;
    getCollectionDetails(variables: NftCollectionDetailsInput): Promise<NftCollectionDetailsResult>;
}

type BalancesByWalletENSInput = CodegenEthMainnetBalancesByWalletENSQueryVariables & NonQueryInput;
type BalancesByWalletENSResult = {
    address: string;
    ensName: string;
    results: CodegenTokenBalanceNodeFragment[];
    pageInfo: CodegenPaginationFragment;
};

type BalancesByWalletAddressQueryVariables = CodegenEthMainnetBalancesByWalletAddressQueryVariables;
type BalancesByWalletAddressInput = BalancesByWalletAddressQueryVariables & NonQueryInput;
type BalancesByWalletAddressResult = {
    address: string;
    ensName: string;
    results: CodegenTokenBalanceNodeFragment[];
    pageInfo: CodegenPaginationFragment;
};

declare class TokensController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getBalancesByWallet(variables: BalancesByWalletAddressInput): Promise<BalancesByWalletENSResult>;
    private getBalancesByWalletENS;
    private getBalancesByWalletAddress;
    private flattenBalanceResponses;
}

type GasPricesQueryVariables = CodegenEthMainnetGasPricesQueryVariables & {
    returnInGwei?: boolean;
};
type GasPricesInput = GasPricesQueryVariables & NonQueryInput;
type GasPricesResult = {
    gasPrices: CodegenGasPrice[];
};

declare class UtilsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getGasPrices(variables: GasPricesInput): Promise<GasPricesResult>;
}

type ContractDetailsQueryVariables = CodegenEthMainnetContractDetailsQueryVariables;
type ContractDetailsInput = ContractDetailsQueryVariables & NonQueryInput;
type ContractDetailsResult = {
    contract: CodegenContractInfoFragment | null;
};

declare class ContractsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getDetails(variables: ContractDetailsInput): Promise<ContractDetailsResult>;
}

type ContractEventsQueryVariables = CodegenEthereumMainnetEventsByContractQueryVariables;
type ContractEventsInput = ContractEventsQueryVariables & NonQueryInput;
type ContractEventsResult = {
    results: CodegenTokenEventInfoFragment[];
    pageInfo: CodegenPaginationFragment;
};

type CollectionEventsQueryVariables = CodegenEthMainnetEventsByCollectionQueryVariables;
type CollectionEventsInput = CollectionEventsQueryVariables & NonQueryInput;
type CollectionEventsResult = {
    results: CodegenTokenEventInfoFragment[];
    pageInfo: CodegenPaginationFragment;
};

type NFTEventsQueryVariables = CodegenEthereumMainnetEventsByNftQueryVariables;
type NFTEventsInput = NFTEventsQueryVariables & NonQueryInput;
type NFTEventsResult = {
    results: CodegenTokenEventInfoFragment[];
    pageInfo: CodegenPaginationFragment;
};

type AllEventsQueryVariables = CodegenEthereumMainnetEventsGetAllQueryVariables;
type AllEventsInput = AllEventsQueryVariables & NonQueryInput;
type AllEventsResult = {
    results: CodegenTokenEventInfoFragment[];
    pageInfo: CodegenPaginationFragment;
};

declare class EventsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getByContract(variables: ContractEventsInput): Promise<ContractEventsResult>;
    getByNFTCollection(variables: CollectionEventsInput): Promise<CollectionEventsResult>;
    getByNFT(variables: NFTEventsInput): Promise<NFTEventsResult>;
    getAll(variables: AllEventsInput): Promise<AllEventsResult>;
}

type TransactionsByWalletAddressQueryVariables = CodegenEthMainnetTransactionsByWalletAddressQueryVariables;
type TransactionsByWalletAddressInput = TransactionsByWalletAddressQueryVariables & NonQueryInput;
type TransactionsByWalletAddressResult = {
    address: string;
    ensName: string;
    results: CodegenTransactionsNodeFragment[];
    pageInfo: CodegenPaginationFragment;
};

type TransactionsByWalletENSQueryVariables = CodegenEthMainnetTransactionsByWalletENSQueryVariables;
type TransactionsByWalletENSInput = TransactionsByWalletENSQueryVariables & NonQueryInput;
type TransactionsByWalletENSResult = {
    address: string;
    ensName: string;
    results: CodegenTransactionsNodeFragment[];
    pageInfo: CodegenPaginationFragment;
};

type TransactionsBySearchQueryVariables = CodegenEthMainnetTransactionsBySearchQueryVariables;
type TransactionsBySearchInput = TransactionsBySearchQueryVariables & NonQueryInput;
type TransactionsBySearchResult = {
    results: CodegenTransactionsNodeFragment[];
    pageInfo: CodegenPaginationFragment;
};

type TransactionsByHashQueryVariables = CodegenEthMainnetTransactionsByHashQueryVariables;
type TransactionsByHashInput = TransactionsByHashQueryVariables & NonQueryInput;
type TransactionsByHashResult = {
    transaction: CodegenTransactionsNodeFragment | null;
};

declare class TransactionsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getByWallet(variables: TransactionsByWalletAddressInput): Promise<TransactionsByWalletAddressResult | TransactionsByWalletENSResult>;
    private getByWalletAddress;
    private getByWalletENS;
    getAll(variables: TransactionsBySearchInput): Promise<TransactionsBySearchResult>;
    getByHash(variables: TransactionsByHashInput): Promise<TransactionsByHashResult>;
}

interface ApiArguments {
    graphApiKey?: string;
    additionalHeaders?: Record<string, string>;
    defaultChain?: ChainName;
}
declare class API {
    readonly urqlClient: Client;
    private customUrqlClient;
    private graphApiKey?;
    private additionalHeaders?;
    readonly defaultChain: ChainName;
    readonly nfts: NftsController;
    readonly tokens: TokensController;
    readonly utils: UtilsController;
    readonly contracts: ContractsController;
    readonly transactions: TransactionsController;
    readonly events: EventsController;
    readonly graphApiClient: Client;
    constructor({ graphApiKey, additionalHeaders, defaultChain, }?: ApiArguments);
    private createUrqlClient;
}

declare const QuickNode: {
    API: typeof API;
};

type WalletNFTsByEnsQueryVariables = CodegenEthMainnetWalletNFTsByEnsQueryVariables;
type WalletNFTsByEnsInput = WalletNFTsByEnsQueryVariables & NonQueryInput;
type WalletNFTsByEnsResult = {
    address: string;
    ensName: string;
    results: CodegenWalletNFTNodeFragment['nft'][];
    pageInfo: CodegenPaginationFragment;
};

export { API, AllEventsInput, AllEventsResult, BalancesByWalletAddressInput, BalancesByWalletAddressResult, BalancesByWalletENSInput, BalancesByWalletENSResult, CollectionEventsInput, CollectionEventsResult, ContractDetailsInput, ContractDetailsResult, ContractEventsInput, ContractEventsResult, GasPricesInput, GasPricesResult, NFTDetailsInput, NFTDetailsResult, NFTEventsInput, NFTEventsResult, NFTTrendingCollectionResult, NFTTrendingCollectionsInput, NFTsByContractAddressInput, NFTsByContractAddressResult, NftCollectionDetailsInput, NftCollectionDetailsResult, TransactionsByHashInput, TransactionsByHashResult, TransactionsBySearchInput, TransactionsBySearchResult, TransactionsByWalletAddressInput, TransactionsByWalletAddressResult, TransactionsByWalletENSInput, TransactionsByWalletENSResult, WalletNFTsByAddressInput, WalletNFTsByAddressResult, WalletNFTsByEnsInput, WalletNFTsByEnsResult, QuickNode as default };
