'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fetch = require('cross-fetch');
var core = require('@urql/core');
var exchangeGraphcache = require('@urql/exchange-graphcache');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var fetch__default = /*#__PURE__*/_interopDefaultLegacy(fetch);

function isConnection(object) {
    return (typeof object === 'object' &&
        !!object &&
        ('edges' in object ||
            'total' in object ||
            'pageInfo' in object ||
            'breadcrumbs' in object));
}
function removeNodesAndEdges(data, options) {
    const keys = Object.keys(data);
    const output = {};
    const keepTypename = options?.keepTypename || false;
    keys
        .filter((key) => {
        if (keepTypename)
            return true;
        return key !== '__typename';
    })
        .forEach((key) => {
        const value = data[key];
        if (typeof value === 'string' ||
            typeof value === 'boolean' ||
            typeof value === 'number' ||
            value === null ||
            value === undefined) {
            return (output[key] = value);
        }
        if (Array.isArray(value)) {
            // An array can just be an array of strings and not edges and nodes
            if (value.every((val) => typeof val === 'string')) {
                return (output[key] = value);
            }
            return (output[key] = value.map((item) => removeNodesAndEdges(item, options)));
        }
        if (isConnection(value)) {
            if (value.breadcrumbs)
                output[`${key}Breadcrumbs`] = value.breadcrumbs;
            if (value.total)
                output[`${key}Total`] = value.total;
            if (value.viewport)
                output[`${key}Viewport`] = value.viewport;
            if (value.pageInfo) {
                const { __typename, ...pageInfoRest } = value.pageInfo;
                output[`${key}PageInfo`] = pageInfoRest;
            }
            return (output[key] = value.edges?.map((item) => {
                if (item.node) {
                    // Don't pass options back in so we only remove the __typename from top-level
                    // We may need to change this in the future if we want to keep the __typename for nested nodes
                    return removeNodesAndEdges(item.node);
                }
                return item;
            }));
        }
        return (output[key] = removeNodesAndEdges(value, options));
    });
    return output;
}

class CustomUrqlClient {
    constructor(urqlClient) {
        this.urqlClient = urqlClient;
    }
    async query(options) {
        const { keepTypename, query, variables, ...additionalOptions } = options;
        const result = await this.urqlClient.query(query, variables, additionalOptions);
        const { error } = result;
        if (error) {
            console.error(error.stack);
            throw error;
        }
        return {
            ...result,
            data: result?.data &&
                removeNodesAndEdges(result.data, {
                    keepTypename,
                }),
        };
    }
}

const CodegenEthMainnetContractDetailsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetContractDetails" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ContractDetails" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ContractInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Contract" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "abi" } }, { "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "supportedErcInterfaces" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenContract" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "decimals" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ContractDetails" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ContractInfo" } }] } }] } }] };
const CodegenEthereumMainnetEventsGetAllDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthereumMainnetEventsGetAll" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "EventsGetAll" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "EventsGetAll" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] };
const CodegenEthereumMainnetEventsByContractDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthereumMainnetEventsByContract" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "EventsByContract" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "EventsByContract" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthMainnetEventsByCollectionDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetEventsByCollection" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "CollectionEventsFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "CollectionEventsFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }] } }] } }] } }] };
const CodegenEthereumMainnetEventsByNftDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthereumMainnetEventsByNft" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftEventsFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftEventsFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "tokenId" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }] } }] } }] } }] };
const CodegenEthMainnetWalletNFTsByContractAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetWalletNFTsByContractAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftsByContractAddressFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ERC1155NFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC1155NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "wallets" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ERC721NFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC721NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "attributes" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "wallet" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftsByContractAddressFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "__typename" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC1155Collection" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nfts" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ERC1155NFTNode" } }] } }] } }] } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC721Collection" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nfts" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ERC721NFTNode" } }] } }] } }] } }] } }] } }] } }] };
const CodegenEthMainnetWalletNFTsByAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetWalletNFTsByAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFTsFilterInput" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletByAddressFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletNFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletByAddressFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByAddress" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "address" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "walletNFTs" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletNFTNode" } }] } }] } }] } }] } }] } }] };
const CodegenEthMainnetWalletNFTsByEnsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetWalletNFTsByEns" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFTsFilterInput" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletByEnsFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletNFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletByEnsFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByENS" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "ensName" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "walletNFTs" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletNFTNode" } }] } }] } }] } }] } }] } }] };
const CodegenEthMainnetNFTDetailsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetNFTDetails" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftDetails" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftDetails" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "tokenId" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC1155NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "wallets" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }] } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC721NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "wallet" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }] } }] } }] };
const CodegenEthMainnetNftCollectionDetailsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetNftCollectionDetails" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftCollectionInfo" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftCollectionInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "bannerImage" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "height" } }, { "kind": "Field", "name": { "kind": "Name", "value": "mimeType" } }, { "kind": "Field", "name": { "kind": "Name", "value": "url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "width" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "baseTokenUri" } }, { "kind": "Field", "name": { "kind": "Name", "value": "circulatingSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "supportedErcInterfaces" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "image" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "height" } }, { "kind": "Field", "name": { "kind": "Name", "value": "mimeType" } }, { "kind": "Field", "name": { "kind": "Name", "value": "url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "width" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ohlcvChart" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "ObjectValue", "fields": [{ "kind": "ObjectField", "name": { "kind": "Name", "value": "limit" }, "value": { "kind": "IntValue", "value": "1" } }] } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "average" } }, { "kind": "Field", "name": { "kind": "Name", "value": "close" } }, { "kind": "Field", "name": { "kind": "Name", "value": "count" } }, { "kind": "Field", "name": { "kind": "Name", "value": "high" } }, { "kind": "Field", "name": { "kind": "Name", "value": "low" } }, { "kind": "Field", "name": { "kind": "Name", "value": "open" } }, { "kind": "Field", "name": { "kind": "Name", "value": "volume" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "openseaMetadata" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "isHidden" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "unsafeSlug" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "slug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "totalSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "twitterUsername" } }] } }] } }] };
const CodegenEthMainnetTrendingCollectionsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetTrendingCollections" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftTrendingCollections" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TrendingCollectionInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Collection" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "baseTokenUri" } }, { "kind": "Field", "name": { "kind": "Name", "value": "circulatingSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "image" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "height" } }, { "kind": "Field", "name": { "kind": "Name", "value": "mimeType" } }, { "kind": "Field", "name": { "kind": "Name", "value": "url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "width" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "openseaMetadata" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "isHidden" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "unsafeSlug" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "totalSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "twitterUsername" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftTrendingCollections" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "trendingCollections" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TrendingCollectionInfo" } }] } }] } }] } }] } }] } }] };
const CodegenEthMainnetBalancesByWalletAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetBalancesByWalletAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GetBalancesByWalletAddressFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenBalanceNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletTokenBalance" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "totalBalance" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "decimals" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GetBalancesByWalletAddressFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByAddress" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "address" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenBalances" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenBalanceNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthMainnetBalancesByWalletENSDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetBalancesByWalletENS" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GetBalancesByWalletENSFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenBalanceNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletTokenBalance" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "totalBalance" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "decimals" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GetBalancesByWalletENSFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByENS" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "ensName" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenBalances" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenBalanceNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthMainnetTransactionsByHashDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetTransactionsByHash" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "hash" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsByHash" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsByHash" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "transaction" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "hash" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "hash" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }] };
const CodegenEthMainnetTransactionsBySearchDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetTransactionsBySearch" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TransactionsFilterInput" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsBySearch" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsBySearch" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "transactions" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] };
const CodegenEthMainnetTransactionsByWalletAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetTransactionsByWalletAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsByWalletAddress" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsByWalletAddress" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByAddress" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "address" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactions" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthMainnetTransactionsByWalletENSDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetTransactionsByWalletENS" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsByWalletENS" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsByWalletENS" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByENS" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "ensName" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactions" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthMainnetGasPricesDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthMainnetGasPrices" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "GasPriceFilterInput" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereum" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GasPrice" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GasPriceInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "GasPrice" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total" } }, { "kind": "Field", "name": { "kind": "Name", "value": "average" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ceiling" } }, { "kind": "Field", "name": { "kind": "Name", "value": "floor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "median" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GasPrice" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "gasPrices" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GasPriceInfo" } }] } }] } }] };
const CodegenEthSepoliaContractDetailsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaContractDetails" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ContractDetails" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ContractInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Contract" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "abi" } }, { "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "supportedErcInterfaces" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenContract" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "decimals" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ContractDetails" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ContractInfo" } }] } }] } }] };
const CodegenEthereumSepoliaEventsGetAllDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthereumSepoliaEventsGetAll" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "EventsGetAll" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "EventsGetAll" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] };
const CodegenEthereumSepoliaEventsByContractDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthereumSepoliaEventsByContract" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "EventsByContract" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "EventsByContract" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthSepoliaEventsByCollectionDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaEventsByCollection" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "CollectionEventsFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "CollectionEventsFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }] } }] } }] } }] };
const CodegenEthSepoliaEventsByNftDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaEventsByNft" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftEventsFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftEventsFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "tokenId" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }] } }] } }] } }] };
const CodegenEthSepoliaWalletNFTsByContractAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaWalletNFTsByContractAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftsByContractAddressFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ERC1155NFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC1155NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "wallets" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ERC721NFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC721NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "attributes" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "wallet" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftsByContractAddressFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "__typename" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC1155Collection" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nfts" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ERC1155NFTNode" } }] } }] } }] } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC721Collection" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nfts" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ERC721NFTNode" } }] } }] } }] } }] } }] } }] } }] };
const CodegenEthSepoliaWalletNFTsByAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaWalletNFTsByAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFTsFilterInput" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletByAddressFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletNFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletByAddressFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByAddress" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "address" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "walletNFTs" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletNFTNode" } }] } }] } }] } }] } }] } }] };
const CodegenEthSepoliaWalletNFTsByEnsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaWalletNFTsByEns" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFTsFilterInput" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletByEnsFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletNFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletByEnsFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByENS" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "ensName" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "walletNFTs" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletNFTNode" } }] } }] } }] } }] } }] } }] };
const CodegenEthSepoliaNFTDetailsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaNFTDetails" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftDetails" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftDetails" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "tokenId" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC1155NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "wallets" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }] } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC721NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "wallet" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }] } }] } }] };
const CodegenEthSepoliaNftCollectionDetailsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaNftCollectionDetails" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftCollectionInfo" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftCollectionInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "bannerImage" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "height" } }, { "kind": "Field", "name": { "kind": "Name", "value": "mimeType" } }, { "kind": "Field", "name": { "kind": "Name", "value": "url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "width" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "baseTokenUri" } }, { "kind": "Field", "name": { "kind": "Name", "value": "circulatingSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "supportedErcInterfaces" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "image" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "height" } }, { "kind": "Field", "name": { "kind": "Name", "value": "mimeType" } }, { "kind": "Field", "name": { "kind": "Name", "value": "url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "width" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ohlcvChart" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "ObjectValue", "fields": [{ "kind": "ObjectField", "name": { "kind": "Name", "value": "limit" }, "value": { "kind": "IntValue", "value": "1" } }] } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "average" } }, { "kind": "Field", "name": { "kind": "Name", "value": "close" } }, { "kind": "Field", "name": { "kind": "Name", "value": "count" } }, { "kind": "Field", "name": { "kind": "Name", "value": "high" } }, { "kind": "Field", "name": { "kind": "Name", "value": "low" } }, { "kind": "Field", "name": { "kind": "Name", "value": "open" } }, { "kind": "Field", "name": { "kind": "Name", "value": "volume" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "openseaMetadata" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "isHidden" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "unsafeSlug" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "slug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "totalSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "twitterUsername" } }] } }] } }] };
const CodegenEthSepoliaTrendingCollectionsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaTrendingCollections" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftTrendingCollections" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TrendingCollectionInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Collection" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "baseTokenUri" } }, { "kind": "Field", "name": { "kind": "Name", "value": "circulatingSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "image" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "height" } }, { "kind": "Field", "name": { "kind": "Name", "value": "mimeType" } }, { "kind": "Field", "name": { "kind": "Name", "value": "url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "width" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "openseaMetadata" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "isHidden" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "unsafeSlug" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "totalSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "twitterUsername" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftTrendingCollections" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "trendingCollections" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TrendingCollectionInfo" } }] } }] } }] } }] } }] } }] };
const CodegenEthSepoliaBalancesByWalletAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaBalancesByWalletAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GetBalancesByWalletAddressFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenBalanceNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletTokenBalance" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "totalBalance" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "decimals" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GetBalancesByWalletAddressFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByAddress" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "address" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenBalances" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenBalanceNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthSepoliaBalancesByWalletENSDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaBalancesByWalletENS" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GetBalancesByWalletENSFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenBalanceNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletTokenBalance" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "totalBalance" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "decimals" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GetBalancesByWalletENSFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByENS" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "ensName" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenBalances" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenBalanceNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthSepoliaTransactionsByHashDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaTransactionsByHash" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "hash" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsByHash" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsByHash" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "transaction" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "hash" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "hash" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }] };
const CodegenEthSepoliaTransactionsBySearchDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaTransactionsBySearch" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TransactionsFilterInput" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsBySearch" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsBySearch" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "transactions" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] };
const CodegenEthSepoliaTransactionsByWalletAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaTransactionsByWalletAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsByWalletAddress" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsByWalletAddress" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByAddress" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "address" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactions" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthSepoliaTransactionsByWalletENSDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaTransactionsByWalletENS" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsByWalletENS" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsByWalletENS" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByENS" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "ensName" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactions" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenEthSepoliaGasPricesDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "EthSepoliaGasPrices" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "GasPriceFilterInput" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "ethereumSepolia" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GasPrice" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GasPriceInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "GasPrice" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total" } }, { "kind": "Field", "name": { "kind": "Name", "value": "average" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ceiling" } }, { "kind": "Field", "name": { "kind": "Name", "value": "floor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "median" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GasPrice" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "gasPrices" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GasPriceInfo" } }] } }] } }] };
const CodegenPolygonMainnetContractDetailsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetContractDetails" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ContractDetails" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ContractInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Contract" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "abi" } }, { "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "supportedErcInterfaces" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenContract" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "decimals" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ContractDetails" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ContractInfo" } }] } }] } }] };
const CodegenPolygonMainnetEventsGetAllDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetEventsGetAll" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "EventsGetAll" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "EventsGetAll" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] };
const CodegenPolygonMainnetEventsByContractDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetEventsByContract" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "EventsByContract" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "EventsByContract" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetEventsByCollectionDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetEventsByCollection" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "CollectionEventsFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "CollectionEventsFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetEventsByNftDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetEventsByNft" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEventsFilterInput" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftEventsFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenEventInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionHash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transferIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenBurnEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenTransferEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenMintEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "tokenQuantity" } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "TokenSaleEvent" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "marketplace" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenContractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "receivedTokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "sentTokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftEventsFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "tokenId" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenEvents" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenEventInfo" } }] } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetNFTsByContractAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetNFTsByContractAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftsByContractAddressFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ERC1155NFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC1155NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "wallets" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "ERC721NFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC721NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "attributes" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "Field", "name": { "kind": "Name", "value": "wallet" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftsByContractAddressFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "__typename" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC1155Collection" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nfts" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ERC1155NFTNode" } }] } }] } }] } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC721Collection" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nfts" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "ERC721NFTNode" } }] } }] } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetWalletNFTsByAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetWalletNFTsByAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFTsFilterInput" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletByAddressFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletNFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletByAddressFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByAddress" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "address" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "walletNFTs" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletNFTNode" } }] } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetWalletNFTsByEnsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetWalletNFTsByEns" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFTsFilterInput" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletByEnsFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletNFTNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletNFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "WalletByEnsFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByENS" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "ensName" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "walletNFTs" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "WalletNFTNode" } }] } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetNFTDetailsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetNFTDetails" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftDetails" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftDetails" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "nft" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "tokenId" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "tokenId" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "animationUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "collectionSlug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "metadata" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenId" } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC1155NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "wallets" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }] } }] } }, { "kind": "InlineFragment", "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "ERC721NFT" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "wallet" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetNftCollectionDetailsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetNftCollectionDetails" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftCollectionInfo" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftCollectionInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "contractAddress" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "contractAddress" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "bannerImage" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "height" } }, { "kind": "Field", "name": { "kind": "Name", "value": "mimeType" } }, { "kind": "Field", "name": { "kind": "Name", "value": "url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "width" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "baseTokenUri" } }, { "kind": "Field", "name": { "kind": "Name", "value": "circulatingSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "supportedErcInterfaces" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "image" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "height" } }, { "kind": "Field", "name": { "kind": "Name", "value": "mimeType" } }, { "kind": "Field", "name": { "kind": "Name", "value": "url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "width" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ohlcvChart" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "ObjectValue", "fields": [{ "kind": "ObjectField", "name": { "kind": "Name", "value": "limit" }, "value": { "kind": "IntValue", "value": "1" } }] } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "average" } }, { "kind": "Field", "name": { "kind": "Name", "value": "close" } }, { "kind": "Field", "name": { "kind": "Name", "value": "count" } }, { "kind": "Field", "name": { "kind": "Name", "value": "high" } }, { "kind": "Field", "name": { "kind": "Name", "value": "low" } }, { "kind": "Field", "name": { "kind": "Name", "value": "open" } }, { "kind": "Field", "name": { "kind": "Name", "value": "volume" } }, { "kind": "Field", "name": { "kind": "Name", "value": "timestamp" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "openseaMetadata" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "isHidden" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "unsafeSlug" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "slug" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "totalSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "twitterUsername" } }] } }] } }] };
const CodegenPolygonMainnetTrendingCollectionsDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetTrendingCollections" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "NftTrendingCollections" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TrendingCollectionInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Collection" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "baseTokenUri" } }, { "kind": "Field", "name": { "kind": "Name", "value": "circulatingSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "externalUrl" } }, { "kind": "Field", "name": { "kind": "Name", "value": "image" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "height" } }, { "kind": "Field", "name": { "kind": "Name", "value": "mimeType" } }, { "kind": "Field", "name": { "kind": "Name", "value": "url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "width" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "openseaMetadata" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "isHidden" } }, { "kind": "Field", "name": { "kind": "Name", "value": "isVerified" } }, { "kind": "Field", "name": { "kind": "Name", "value": "unsafeSlug" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "totalSupply" } }, { "kind": "Field", "name": { "kind": "Name", "value": "twitterUsername" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "NftTrendingCollections" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "trendingCollections" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "collection" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TrendingCollectionInfo" } }] } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetBalancesByWalletAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetBalancesByWalletAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GetBalancesByWalletAddressFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenBalanceNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletTokenBalance" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "totalBalance" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "decimals" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GetBalancesByWalletAddressFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByAddress" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "address" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenBalances" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenBalanceNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetBalancesByWalletENSDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetBalancesByWalletENS" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GetBalancesByWalletENSFragment" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TokenBalanceNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "WalletTokenBalance" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "totalBalance" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contract" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "decimals" } }, { "kind": "Field", "name": { "kind": "Name", "value": "name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "symbol" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GetBalancesByWalletENSFragment" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByENS" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "ensName" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "tokenBalances" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TokenBalanceNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetTransactionsByHashDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetTransactionsByHash" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "hash" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsByHash" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsByHash" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "transaction" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "hash" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "hash" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }] };
const CodegenPolygonMainnetTransactionsBySearchDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetTransactionsBySearch" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "TransactionsFilterInput" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsBySearch" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsBySearch" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "transactions" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] };
const CodegenPolygonMainnetTransactionsByWalletAddressDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetTransactionsByWalletAddress" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsByWalletAddress" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsByWalletAddress" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByAddress" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "address" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "address" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactions" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetTransactionsByWalletENSDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetTransactionsByWalletENS" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } }, "type": { "kind": "NonNullType", "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "Int" } } }, { "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "String" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsByWalletENS" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsNode" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "Transaction" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "blockTimestamp" } }, { "kind": "Field", "name": { "kind": "Name", "value": "contractAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "fromAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "cumulativeGasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "effectiveGasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasPrice" } }, { "kind": "Field", "name": { "kind": "Name", "value": "gasUsed" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hash" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "maxPriorityFeePerGas" } }, { "kind": "Field", "name": { "kind": "Name", "value": "toAddress" } }, { "kind": "Field", "name": { "kind": "Name", "value": "type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "input" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactionIndex" } }, { "kind": "Field", "name": { "kind": "Name", "value": "value" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "Pagination" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "PageInfo" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "endCursor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasNextPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "hasPreviousPage" } }, { "kind": "Field", "name": { "kind": "Name", "value": "startCursor" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "TransactionsByWalletENS" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "walletByENS" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "ensName" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "ensName" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "address" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ensName" } }, { "kind": "Field", "name": { "kind": "Name", "value": "transactions" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "first" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "first" } } }, { "kind": "Argument", "name": { "kind": "Name", "value": "after" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "after" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "edges" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "node" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "TransactionsNode" } }] } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "pageInfo" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "Pagination" } }] } }] } }] } }] } }] };
const CodegenPolygonMainnetGasPricesDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "PolygonMainnetGasPrices" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "GasPriceFilterInput" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "polygon" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GasPrice" } }] } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GasPriceInfo" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "GasPrice" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "blockNumber" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total" } }, { "kind": "Field", "name": { "kind": "Name", "value": "average" } }, { "kind": "Field", "name": { "kind": "Name", "value": "ceiling" } }, { "kind": "Field", "name": { "kind": "Name", "value": "floor" } }, { "kind": "Field", "name": { "kind": "Name", "value": "median" } }] } }, { "kind": "FragmentDefinition", "name": { "kind": "Name", "value": "GasPrice" }, "typeCondition": { "kind": "NamedType", "name": { "kind": "Name", "value": "EVMSchemaType" } }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "gasPrices" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "filter" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "filter" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "FragmentSpread", "name": { "kind": "Name", "value": "GasPriceInfo" } }] } }] } }] };

// Formats the query result with the edges and nodes removed into what we want to return to the user
function formatQueryResult(queryResult, resultsKey, // Key that the actual results are in
paginationKey, // Key that the pagination info is in
resultsKeyToRemove, // Key that the results are nested under to remove for each entry
additionalModification) {
    const additionaProperties = Object.fromEntries(Object.entries(queryResult).filter(([key]) => key !== resultsKey && key !== paginationKey));
    let trimmedResults = queryResult[resultsKey];
    if (resultsKeyToRemove) {
        trimmedResults = trimmedResults.map((result) => result[resultsKeyToRemove] || {});
    }
    const formattedResultBase = {
        results: trimmedResults,
        pageInfo: queryResult[paginationKey],
    };
    let result = {
        ...formattedResultBase,
        ...additionaProperties,
    };
    if (additionalModification)
        result = additionalModification(result);
    return result;
}

const emptyPageInfo = {
    endCursor: null,
    hasNextPage: false,
    hasPreviousPage: false,
    startCursor: null,
};
function weiToGwei(wei) {
    return +(wei / 1e9).toFixed(2);
}

const DEFAULT_CHAIN = 'ethereum';

/**
 * https://eips.ethereum.org/EIPS/eip-137#name-syntax
 *
 * explanation of the regex pattern:
 * ^  Matches the start of the string
 * (?=.{3,255}$) Lookahead assertion for the length of the string (3 to 255 characters)
 * [\p{L}\p{N}\p{Pd}\p{M}\p{S}\u{1F300}-\u{1F6FF}]+  Matches one or more Unicode letter, number, punctuation, symbol, or character in the specified emoji range
 * (\.[\p{L}\p{N}\p{Pd}\p{M}\p{S}\u{1F300}-\u{1F6FF}]+)*  Matches zero or more occurrences of a dot followed by one or more Unicode characters
 * \.(?:eth|xyz|art)  Matches a dot followed by either 'eth', 'xyz', or 'art'
 * $  Matches the end of the string
 *
 */
function isValidENSAddress(ensAddress) {
    const allowedTLDs = ['eth', 'xyz', 'art'];
    const unicodeAndEmojis = '[\\p{L}\\p{N}\\p{Pd}\\p{M}\\p{S}\\u{1F300}-\\u{1F6FF}]';
    const regexPattern = `^(?=.{3,255}$)${unicodeAndEmojis}+(\\.${unicodeAndEmojis}+)*\\.(?:${allowedTLDs.join('|')})$`;
    const regex = new RegExp(regexPattern, 'mu');
    return regex.test(ensAddress);
}

class NftsController {
    constructor(client, defaultChain = DEFAULT_CHAIN) {
        this.client = client;
        this.defaultChain = defaultChain;
    }
    async getByWallet(variables) {
        const { address, ...allVariables } = variables;
        if (isValidENSAddress(address)) {
            return this.getByWalletENS({
                ensName: address,
                ...allVariables,
            });
        }
        return this.getByWalletAddress({
            address,
            ...allVariables,
        });
    }
    async getByWalletENS(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetWalletNFTsByEnsDocument,
            polygon: CodegenPolygonMainnetWalletNFTsByEnsDocument,
            ethereumSepolia: CodegenEthSepoliaWalletNFTsByEnsDocument,
        };
        const { data: { [userChain]: { walletByENS }, }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        if (!walletByENS?.walletNFTs?.length) {
            // Address can still be valid ENS name, but not have any NFTs
            const address = walletByENS?.address || '';
            const ensName = walletByENS?.ensName || '';
            return {
                address: address,
                ensName: ensName,
                results: [],
                pageInfo: emptyPageInfo,
            };
        }
        const formattedResult = formatQueryResult(walletByENS, 'walletNFTs', 'walletNFTsPageInfo', 'nft');
        return formattedResult;
    }
    async getByWalletAddress(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetWalletNFTsByAddressDocument,
            polygon: CodegenPolygonMainnetWalletNFTsByAddressDocument,
            ethereumSepolia: CodegenEthSepoliaWalletNFTsByAddressDocument,
        };
        const { data: { [userChain]: { walletByAddress }, }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        if (!walletByAddress?.walletNFTs?.length) {
            const address = walletByAddress?.address || '';
            const ensName = walletByAddress?.ensName || '';
            return {
                address: address,
                ensName: ensName,
                results: [],
                pageInfo: emptyPageInfo,
            };
        }
        const formattedResult = formatQueryResult(walletByAddress, 'walletNFTs', 'walletNFTsPageInfo', 'nft');
        return formattedResult;
    }
    async getTrendingCollections(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetTrendingCollectionsDocument,
            polygon: CodegenPolygonMainnetTrendingCollectionsDocument,
            ethereumSepolia: CodegenEthSepoliaTrendingCollectionsDocument,
        };
        const { data: { [userChain]: trendingCollections }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        if (!trendingCollections?.trendingCollections?.length) {
            return { results: [], pageInfo: emptyPageInfo };
        }
        const formattedResult = formatQueryResult(trendingCollections, 'trendingCollections', 'trendingCollectionsPageInfo', 'collection');
        return formattedResult;
    }
    async getByContractAddress(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetWalletNFTsByContractAddressDocument,
            polygon: CodegenPolygonMainnetNFTsByContractAddressDocument,
            ethereumSepolia: CodegenEthSepoliaWalletNFTsByContractAddressDocument,
        };
        const { data: { [userChain]: { collection }, }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
            keepTypename: true,
        });
        if (!collection?.nfts?.length) {
            return {
                standard: null,
                results: [],
                pageInfo: emptyPageInfo,
            };
        }
        const setErcStandard = (results) => {
            const standardMap = {
                ERC1155Collection: 'ERC1155',
                ERC721Collection: 'ERC721',
            };
            // Remove address too since it was only used as a key field
            const { __typename, address, ...newResults } = results;
            return {
                ...newResults,
                standard: standardMap[results['__typename']] || null,
            };
        };
        const formattedResult = formatQueryResult(collection, 'nfts', 'nftsPageInfo', null, setErcStandard);
        return formattedResult;
    }
    async getNFTDetails(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetNFTDetailsDocument,
            polygon: CodegenPolygonMainnetNFTDetailsDocument,
            ethereumSepolia: CodegenEthSepoliaNFTDetailsDocument,
        };
        const { data: { [userChain]: { nft }, }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        if (nft)
            return { nft };
        return { nft: null };
    }
    async getCollectionDetails(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetNftCollectionDetailsDocument,
            polygon: CodegenPolygonMainnetNftCollectionDetailsDocument,
            ethereumSepolia: CodegenEthSepoliaNftCollectionDetailsDocument,
        };
        const { data: { [userChain]: { collection }, }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        if (collection)
            return { collection };
        return { collection: null };
    }
}

class TokensController {
    constructor(client, defaultChain = DEFAULT_CHAIN) {
        this.client = client;
        this.defaultChain = defaultChain;
    }
    async getBalancesByWallet(variables) {
        const { address, ...allVariables } = variables;
        if (isValidENSAddress(address)) {
            return this.getBalancesByWalletENS({
                ensName: address,
                ...allVariables,
            });
        }
        return this.getBalancesByWalletAddress({
            address,
            ...allVariables,
        });
    }
    async getBalancesByWalletENS(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetBalancesByWalletENSDocument,
            polygon: CodegenPolygonMainnetBalancesByWalletENSDocument,
            ethereumSepolia: CodegenEthSepoliaBalancesByWalletENSDocument,
        };
        const { data: { [userChain]: { walletByENS }, }, } = await this.client.query({
            variables: queryVariables,
            query: query[userChain],
        });
        if (!walletByENS?.tokenBalances?.length) {
            // Address can still be valid ENS name, but not have any balances
            const address = walletByENS?.address || '';
            const ensName = walletByENS?.ensName || '';
            return {
                address: address,
                ensName: ensName,
                results: [],
                pageInfo: emptyPageInfo,
            };
        }
        const formattedResult = formatQueryResult(walletByENS, 'tokenBalances', 'tokenBalancesPageInfo', null, this.flattenBalanceResponses // Remove the "contract" key and move info to balance result body
        );
        return formattedResult;
    }
    async getBalancesByWalletAddress(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetBalancesByWalletAddressDocument,
            polygon: CodegenPolygonMainnetBalancesByWalletAddressDocument,
            ethereumSepolia: CodegenEthSepoliaBalancesByWalletAddressDocument,
        };
        const { data: { [userChain]: { walletByAddress }, }, } = await this.client.query({
            variables: queryVariables,
            query: query[userChain],
        });
        if (!walletByAddress?.tokenBalances?.length) {
            // Address can still be valid address, but not have any balances
            const address = walletByAddress?.address || '';
            const ensName = walletByAddress?.ensName || '';
            return {
                address: address,
                ensName: ensName,
                results: [],
                pageInfo: emptyPageInfo,
            };
        }
        const formattedResult = formatQueryResult(walletByAddress, 'tokenBalances', 'tokenBalancesPageInfo', null, this.flattenBalanceResponses // Remove the "contract" key and move info to balance result body
        );
        return formattedResult;
    }
    flattenBalanceResponses(response) {
        const modifiedResults = response.results.map((result) => {
            const { contract: { ...contractInfo }, ...balanceInfo } = result;
            return { ...balanceInfo, ...contractInfo };
        });
        response.results = modifiedResults;
        return response;
    }
}

class UtilsController {
    constructor(client, defaultChain = DEFAULT_CHAIN) {
        this.client = client;
        this.defaultChain = defaultChain;
    }
    async getGasPrices(variables) {
        const { chain, ...queryVariables } = variables;
        const returnInGwei = variables.returnInGwei || false;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetGasPricesDocument,
            polygon: CodegenPolygonMainnetGasPricesDocument,
            ethereumSepolia: CodegenEthSepoliaGasPricesDocument,
        };
        const { data: { [userChain]: { gasPrices }, }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        if (Array.isArray(gasPrices) && gasPrices.length > 0) {
            if (returnInGwei) {
                const fieldsToTransform = [
                    'total',
                    'average',
                    'ceiling',
                    'floor',
                    'median',
                ];
                const modifiedGasPrices = gasPrices.map((gasPrice) => {
                    fieldsToTransform.map((field) => {
                        gasPrice[field] = weiToGwei(gasPrice[field]);
                    });
                    return gasPrice;
                });
                return { gasPrices: modifiedGasPrices };
            }
            return { gasPrices };
        }
        return { gasPrices: [] };
    }
}

class ContractsController {
    constructor(client, defaultChain = DEFAULT_CHAIN) {
        this.client = client;
        this.defaultChain = defaultChain;
    }
    async getDetails(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetContractDetailsDocument,
            polygon: CodegenPolygonMainnetContractDetailsDocument,
            ethereumSepolia: CodegenEthSepoliaContractDetailsDocument,
        };
        const { data: { [userChain]: { contract }, }, } = await this.client.query({
            variables: queryVariables,
            query: query[userChain],
        });
        if (contract)
            return { contract };
        return { contract: null };
    }
}

class EventsController {
    constructor(client, defaultChain = DEFAULT_CHAIN) {
        this.client = client;
        this.defaultChain = defaultChain;
    }
    async getByContract(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthereumMainnetEventsByContractDocument,
            polygon: CodegenPolygonMainnetEventsByContractDocument,
            ethereumSepolia: CodegenEthereumSepoliaEventsByContractDocument,
        };
        const { data: { [userChain]: { contract }, }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        if (!contract?.tokenEvents?.length) {
            return {
                results: [],
                pageInfo: emptyPageInfo,
            };
        }
        const formattedResult = formatQueryResult(contract, 'tokenEvents', 'tokenEventsPageInfo');
        return formattedResult;
    }
    async getByNFTCollection(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetEventsByCollectionDocument,
            polygon: CodegenPolygonMainnetEventsByCollectionDocument,
            ethereumSepolia: CodegenEthSepoliaEventsByCollectionDocument,
        };
        const { data: { [userChain]: { collection }, }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        if (!collection?.tokenEvents?.length)
            return { results: [], pageInfo: emptyPageInfo };
        function removeKeyFields(results) {
            const { address, ...newResults } = results;
            return newResults;
        }
        const formattedResult = formatQueryResult(collection, 'tokenEvents', 'tokenEventsPageInfo', null, removeKeyFields);
        return formattedResult;
    }
    async getByNFT(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthereumMainnetEventsByNftDocument,
            polygon: CodegenPolygonMainnetEventsByNftDocument,
            ethereumSepolia: CodegenEthSepoliaEventsByNftDocument,
        };
        const { data: { [userChain]: { nft }, }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        if (!nft?.tokenEvents?.length)
            return { results: [], pageInfo: emptyPageInfo };
        function removeKeyFields(results) {
            const { contractAddress, tokenId, ...newResults } = results;
            return newResults;
        }
        const formattedResult = formatQueryResult(nft, 'tokenEvents', 'tokenEventsPageInfo', null, removeKeyFields);
        return formattedResult;
    }
    async getAll(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthereumMainnetEventsGetAllDocument,
            polygon: CodegenPolygonMainnetEventsGetAllDocument,
            ethereumSepolia: CodegenEthereumSepoliaEventsGetAllDocument,
        };
        const { data: { [userChain]: tokenEvents }, } = await this.client.query({
            query: query[userChain],
            variables: queryVariables,
        });
        const formattedResult = formatQueryResult(tokenEvents, 'tokenEvents', 'tokenEventsPageInfo');
        return formattedResult;
    }
}

var __schema={queryType:{name:"Query"},mutationType:null,subscriptionType:null,types:[{kind:"SCALAR",name:"BigInt",description:"The `BigInt` scalar type represents non-fractional signed whole numeric values.",fields:null,inputFields:null,interfaces:null,enumValues:null,possibleTypes:null},{kind:"SCALAR",name:"Boolean",description:"The `Boolean` scalar type represents `true` or `false`.",fields:null,inputFields:null,interfaces:null,enumValues:null,possibleTypes:null},{kind:"INTERFACE",name:"Collection",description:null,fields:[{name:"address",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"attributes",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"CollectionAttributesConnection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"bannerImage",description:"Collection banner image.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenUpload",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"baseTokenUri",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"circulatingSupply",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[],type:{kind:"OBJECT",name:"NFTContract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"externalUrl",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"holders",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionHoldersConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"image",description:"The collection image.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenUpload",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"ohlcvChart",description:null,args:[{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"CollectionOhlcvChartInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionOHLCVChart",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"openseaMetadata",description:null,args:[],type:{kind:"OBJECT",name:"OpenSeaMetadata",ofType:null},isDeprecated:false,deprecationReason:null},{name:"orderHistory",description:null,args:[{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"CollectionOrderHistoryInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionOrderHistory",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"slug",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"symbol",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalSupply",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"twitterUsername",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"wallets",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionWalletsConnection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:[{kind:"OBJECT",name:"ERC721Collection",ofType:null},{kind:"OBJECT",name:"ERC1155Collection",ofType:null}]},{kind:"OBJECT",name:"CollectionAttribute",description:"A contract's attribute count",fields:[{name:"name",description:"The trait key.",args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"value",description:"The value of the trait.",args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionAttributesConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionAttributesConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionAttributesConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionAttribute",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionHoldersConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionHoldersConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionHoldersConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"NFTWallet",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionOHLCVChart",description:"Collection OHLCV chart stats",fields:[{name:"average",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"close",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"count",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Float",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"high",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"low",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"open",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"timestamp",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"DateTime",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"volume",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"ENUM",name:"CollectionOHLCVChartInterval",description:"Filter by input interval",fields:null,inputFields:null,interfaces:null,enumValues:[{name:"FIFTEEN_MINUTES",description:null,isDeprecated:false,deprecationReason:null},{name:"FIVE_MINUTES",description:null,isDeprecated:false,deprecationReason:null},{name:"ONE_DAY",description:null,isDeprecated:false,deprecationReason:null},{name:"ONE_HOUR",description:null,isDeprecated:false,deprecationReason:null},{name:"ONE_MINUTE",description:null,isDeprecated:false,deprecationReason:null},{name:"SEVEN_DAYS",description:null,isDeprecated:false,deprecationReason:null},{name:"SIX_HOURS",description:null,isDeprecated:false,deprecationReason:null},{name:"THIRTY_DAYS",description:null,isDeprecated:false,deprecationReason:null},{name:"THIRTY_MINUTES",description:null,isDeprecated:false,deprecationReason:null},{name:"TWELVE_HOURS",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"INPUT_OBJECT",name:"CollectionOhlcvChartInput",description:null,fields:null,inputFields:[{name:"confirmedAtGte",description:null,type:{kind:"SCALAR",name:"DateTime",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"confirmedAtLte",description:null,type:{kind:"SCALAR",name:"DateTime",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"interval",description:null,type:{kind:"ENUM",name:"CollectionOHLCVChartInterval",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"limit",description:null,type:{kind:"SCALAR",name:"Float",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionOrderHistory",description:"Collection order history summary",fields:[{name:"fromAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"priceInEth",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Float",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"timestamp",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"DateTime",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"toAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"tokenId",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transactionHash",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"CollectionOrderHistoryInput",description:null,fields:null,inputFields:[{name:"confirmedAtGte",description:null,type:{kind:"SCALAR",name:"DateTime",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"confirmedAtLte",description:null,type:{kind:"SCALAR",name:"DateTime",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"isLimited",description:null,type:{kind:"SCALAR",name:"Boolean",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionSale",description:"Sale of a collection token",fields:[{name:"estimatedConfirmedAt",description:null,args:[],type:{kind:"SCALAR",name:"DateTime",ofType:null},isDeprecated:false,deprecationReason:null},{name:"priceInEth",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"quantitySold",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"ENUM",name:"CollectionStandard",description:null,fields:null,inputFields:null,interfaces:null,enumValues:[{name:"ERC721",description:null,isDeprecated:false,deprecationReason:null},{name:"ERC1155",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"INPUT_OBJECT",name:"CollectionStandardInput",description:null,fields:null,inputFields:[{name:"eq",description:null,type:{kind:"ENUM",name:"CollectionStandard",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"in",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"CollectionStandard",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"notIn",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"CollectionStandard",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionStats",description:"Stats of a collection",fields:[{name:"average",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"ceiling",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"floor",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"totalSales",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null},{name:"volume",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionTokenEventsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionTokenEventsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionTokenEventsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"INTERFACE",name:"TokenEvent",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionWalletsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionWalletsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"CollectionWalletsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"Wallet",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"CollectionsFilterInput",description:"Filter input for collections",fields:null,inputFields:[{name:"address",description:null,type:{kind:"INPUT_OBJECT",name:"StringInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"ercStandard",description:null,type:{kind:"INPUT_OBJECT",name:"CollectionStandardInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"INTERFACE",name:"Contract",description:null,fields:[{name:"abi",description:null,args:[],type:{kind:"SCALAR",name:"JSON",ofType:null},isDeprecated:false,deprecationReason:null},{name:"address",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"isVerified",description:"Contract with verified ABI",args:[],type:{kind:"SCALAR",name:"Boolean",ofType:null},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"supportedErcInterfaces",description:null,args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"symbol",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ContractTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:[{kind:"OBJECT",name:"NFTContract",ofType:null},{kind:"OBJECT",name:"TokenContract",ofType:null}]},{kind:"ENUM",name:"ContractStandard",description:null,fields:null,inputFields:null,interfaces:null,enumValues:[{name:"ERC20",description:null,isDeprecated:false,deprecationReason:null},{name:"ERC721",description:null,isDeprecated:false,deprecationReason:null},{name:"ERC1155",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"INPUT_OBJECT",name:"ContractStandardInput",description:null,fields:null,inputFields:[{name:"eq",description:null,type:{kind:"ENUM",name:"ContractStandard",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"in",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"ContractStandard",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"notIn",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"ContractStandard",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ContractTokenEventsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ContractTokenEventsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ContractTokenEventsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"INTERFACE",name:"TokenEvent",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ContractsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ContractsEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ContractsEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"INTERFACE",name:"Contract",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"ContractsFilterInput",description:"Filter input for contracts",fields:null,inputFields:[{name:"address",description:null,type:{kind:"INPUT_OBJECT",name:"StringInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"SCALAR",name:"DateTime",description:"A date-time string at UTC, such as 2007-12-03T10:15:30Z, compliant with the `date-time` format outlined in section 5.6 of the RFC 3339 profile of the ISO 8601 standard for representation of dates and times using the Gregorian calendar.",fields:null,inputFields:null,interfaces:null,enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"DateTimeInput",description:null,fields:null,inputFields:[{name:"eq",description:null,type:{kind:"SCALAR",name:"DateTime",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"gt",description:null,type:{kind:"SCALAR",name:"DateTime",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"gte",description:null,type:{kind:"SCALAR",name:"DateTime",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"lt",description:null,type:{kind:"SCALAR",name:"DateTime",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"lte",description:null,type:{kind:"SCALAR",name:"DateTime",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC721Collection",description:null,fields:[{name:"address",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"attributes",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"CollectionAttributesConnection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"bannerImage",description:"Collection banner image.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenUpload",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"baseTokenUri",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"circulatingSupply",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[],type:{kind:"OBJECT",name:"NFTContract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"externalUrl",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"holders",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionHoldersConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"image",description:"The collection image.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenUpload",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"nft",description:null,args:[{name:"tokenId",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"ERC721NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"nfts",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"NFTsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC721CollectionTokensConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"ohlcvChart",description:null,args:[{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"CollectionOhlcvChartInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionOHLCVChart",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"openseaMetadata",description:null,args:[],type:{kind:"OBJECT",name:"OpenSeaMetadata",ofType:null},isDeprecated:false,deprecationReason:null},{name:"orderHistory",description:null,args:[{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"CollectionOrderHistoryInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionOrderHistory",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"slug",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"stats",description:null,args:[{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"ERC721CollectionStatsInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"CollectionStats",ofType:null},isDeprecated:false,deprecationReason:null},{name:"symbol",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalSupply",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"twitterUsername",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"wallets",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionWalletsConnection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"Collection",ofType:null}],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"ERC721CollectionStatsInput",description:null,fields:null,inputFields:[{name:"timeRange",description:null,type:{kind:"INPUT_OBJECT",name:"DateTimeInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC721CollectionTokensConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC721CollectionTokensEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC721CollectionTokensEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC721NFT",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC721NFT",description:null,fields:[{name:"animationUrl",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"attributes",description:"The attributes of the token.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenAttribute",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"collection",description:null,args:[],type:{kind:"OBJECT",name:"ERC721Collection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"collectionSlug",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[],type:{kind:"OBJECT",name:"NFTContract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"externalUrl",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"holder",description:null,args:[],type:{kind:"OBJECT",name:"NFTWallet",ofType:null},isDeprecated:true,deprecationReason:"Use nft.wallet instead"},{name:"metadata",description:null,args:[],type:{kind:"SCALAR",name:"JSONObject",ofType:null},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"NFTTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"tokenId",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"uploads",description:"The uploads of a token.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenUpload",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"wallet",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"NFT",ofType:null}],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC1155Collection",description:null,fields:[{name:"address",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"attributes",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"CollectionAttributesConnection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"bannerImage",description:"Collection banner image.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenUpload",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"baseTokenUri",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"circulatingSupply",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[],type:{kind:"OBJECT",name:"NFTContract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"externalUrl",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"holders",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionHoldersConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"image",description:"The collection image.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenUpload",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"nft",description:null,args:[{name:"tokenId",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"ERC1155NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"nfts",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"NFTsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC1155CollectionTokensConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"ohlcvChart",description:null,args:[{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"CollectionOhlcvChartInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionOHLCVChart",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"openseaMetadata",description:null,args:[],type:{kind:"OBJECT",name:"OpenSeaMetadata",ofType:null},isDeprecated:false,deprecationReason:null},{name:"orderHistory",description:null,args:[{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"CollectionOrderHistoryInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionOrderHistory",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"slug",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"stats",description:null,args:[{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"ERC1155CollectionStatsInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"CollectionStats",ofType:null},isDeprecated:false,deprecationReason:null},{name:"symbol",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalSupply",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"twitterUsername",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"wallets",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionWalletsConnection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"Collection",ofType:null}],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"ERC1155CollectionStatsInput",description:null,fields:null,inputFields:[{name:"timeRange",description:null,type:{kind:"INPUT_OBJECT",name:"DateTimeInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC1155CollectionTokensConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC1155CollectionTokensEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC1155CollectionTokensEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC1155NFT",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC1155NFT",description:null,fields:[{name:"animationUrl",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"collection",description:null,args:[],type:{kind:"OBJECT",name:"ERC1155Collection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"collectionSlug",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[],type:{kind:"OBJECT",name:"NFTContract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"externalUrl",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"holders",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC1155NFTHoldersConnection",ofType:null}},isDeprecated:true,deprecationReason:"Use nft.wallets instead"},{name:"metadata",description:null,args:[],type:{kind:"SCALAR",name:"JSONObject",ofType:null},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"NFTTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"tokenId",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"uploads",description:"The uploads of a token.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenUpload",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"wallets",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC1155NFTWalletsConnection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"NFT",ofType:null}],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC1155NFTHoldersConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC1155NFTHoldersConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC1155NFTHoldersConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"NFTWallet",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC1155NFTWalletsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ERC1155NFTWalletsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"ERC1155NFTWalletsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"Wallet",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"ENUM",name:"ERCStandard",description:null,fields:null,inputFields:null,interfaces:null,enumValues:[{name:"ERC20",description:null,isDeprecated:false,deprecationReason:null},{name:"ERC721",description:null,isDeprecated:false,deprecationReason:null},{name:"ERC1155",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"OBJECT",name:"EVMSchemaType",description:null,fields:[{name:"collection",description:null,args:[{name:"contractAddress",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"INTERFACE",name:"Collection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"collections",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"CollectionsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaTypeCollectionsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[{name:"contractAddress",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"INTERFACE",name:"Contract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contracts",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"ContractsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ContractsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"gasPrices",description:"Fetch historical gas prices by block number.",args:[{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"GasPriceFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results based on blockNumber: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"GasPrice",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"nft",description:null,args:[{name:"contractAddress",description:"The address of the contract that the nft is under",type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"tokenId",description:"The id of the nft",type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"INTERFACE",name:"NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaTypeTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"transaction",description:null,args:[{name:"hash",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"Transaction",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transactions",description:"Returns a list of transactions. Ordered by block number and index.",args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TransactionsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"EVMSchemaTypeTransactionsConnection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"trendingCollections",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TrendingCollectionsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderBy",description:null,type:{kind:"ENUM",name:"TrendingOrderBy",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaTypeTrendingCollectionsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"walletByAddress",description:null,args:[{name:"address",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"walletByENS",description:null,args:[{name:"ensName",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"EVMSchemaTypeCollectionsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaTypeCollectionsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"EVMSchemaTypeCollectionsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"INTERFACE",name:"Collection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"EVMSchemaTypeTokenEventsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaTypeTokenEventsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"EVMSchemaTypeTokenEventsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"INTERFACE",name:"TokenEvent",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"EVMSchemaTypeTransactionsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaTypeTransactionsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"EVMSchemaTypeTransactionsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"Transaction",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"EVMSchemaTypeTrendingCollectionsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaTypeTrendingCollectionsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"EVMSchemaTypeTrendingCollectionsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TrendingCollection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"SCALAR",name:"Float",description:"The `Float` scalar type represents signed double-precision fractional values as specified by [IEEE 754](https://en.wikipedia.org/wiki/IEEE_floating_point).",fields:null,inputFields:null,interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"GasPrice",description:"Gas Prices for a given block. Gas values are returned in Wei.",fields:[{name:"average",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Float",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"blockNumber",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"ceiling",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Float",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"floor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Float",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"median",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Float",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"total",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Float",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"GasPriceFilterInput",description:"Filter input for gas prices",fields:null,inputFields:[{name:"blockNumber",description:null,type:{kind:"INPUT_OBJECT",name:"IntegerInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"SCALAR",name:"Int",description:"The `Int` scalar type represents non-fractional signed whole numeric values. Int can represent values between -(2^31) and 2^31 - 1.",fields:null,inputFields:null,interfaces:null,enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"IntegerInput",description:null,fields:null,inputFields:[{name:"eq",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"gt",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"gte",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"in",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"lt",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"lte",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"SCALAR",name:"JSON",description:"The `JSON` scalar type represents JSON values as specified by [ECMA-404](http://www.ecma-international.org/publications/files/ECMA-ST/ECMA-404.pdf).",fields:null,inputFields:null,interfaces:null,enumValues:null,possibleTypes:null},{kind:"SCALAR",name:"JSONObject",description:"The `JSONObject` scalar type represents JSON objects as specified by [ECMA-404](http://www.ecma-international.org/publications/files/ECMA-ST/ECMA-404.pdf).",fields:null,inputFields:null,interfaces:null,enumValues:null,possibleTypes:null},{kind:"ENUM",name:"Marketplace",description:"Marketplace where the token was sold",fields:null,inputFields:null,interfaces:null,enumValues:[{name:"BLUR",description:null,isDeprecated:false,deprecationReason:null},{name:"CRYPTOPUNKS",description:null,isDeprecated:false,deprecationReason:null},{name:"LOOKSRARE",description:null,isDeprecated:false,deprecationReason:null},{name:"NIFTY_GATEWAY",description:null,isDeprecated:false,deprecationReason:null},{name:"OPENSEA",description:null,isDeprecated:false,deprecationReason:null},{name:"SEAPORT",description:null,isDeprecated:false,deprecationReason:null},{name:"X2Y2",description:null,isDeprecated:false,deprecationReason:null},{name:"ZEROX",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"INPUT_OBJECT",name:"MarketplaceInput",description:null,fields:null,inputFields:[{name:"eq",description:null,type:{kind:"ENUM",name:"Marketplace",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"in",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"Marketplace",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"notIn",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"Marketplace",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"INTERFACE",name:"NFT",description:null,fields:[{name:"animationUrl",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"collection",description:null,args:[],type:{kind:"INTERFACE",name:"Collection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"collectionSlug",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[],type:{kind:"OBJECT",name:"NFTContract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"externalUrl",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"metadata",description:null,args:[],type:{kind:"SCALAR",name:"JSONObject",ofType:null},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"NFTTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"tokenId",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"uploads",description:"The uploads of a token.",args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"TokenUpload",ofType:null}}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:[{kind:"OBJECT",name:"ERC721NFT",ofType:null},{kind:"OBJECT",name:"ERC1155NFT",ofType:null}]},{kind:"OBJECT",name:"NFTContract",description:null,fields:[{name:"abi",description:null,args:[],type:{kind:"SCALAR",name:"JSON",ofType:null},isDeprecated:false,deprecationReason:null},{name:"address",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"collection",description:null,args:[],type:{kind:"INTERFACE",name:"Collection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"isVerified",description:"Contract with verified ABI",args:[],type:{kind:"SCALAR",name:"Boolean",ofType:null},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"supportedErcInterfaces",description:null,args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"symbol",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ContractTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"Contract",ofType:null}],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"NFTTokenEventsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"NFTTokenEventsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"NFTTokenEventsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"INTERFACE",name:"TokenEvent",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"NFTWallet",description:null,fields:[{name:"owner",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"walletAddress",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"NFTsFilterInput",description:null,fields:null,inputFields:[{name:"contractAddressIn",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"OpenSeaMetadata",description:"Metadata provided by opensea",fields:[{name:"isHidden",description:"Collection is hidden on Opensea.",args:[],type:{kind:"SCALAR",name:"Boolean",ofType:null},isDeprecated:false,deprecationReason:null},{name:"isVerified",description:"Collection verified by Opensea.",args:[],type:{kind:"SCALAR",name:"Boolean",ofType:null},isDeprecated:false,deprecationReason:null},{name:"unsafeSlug",description:"Slug provided by Opensea (it might be stale).",args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"ENUM",name:"OrderDirection",description:"Sort ascending (A-Z) or descending (Z-A)",fields:null,inputFields:null,interfaces:null,enumValues:[{name:"ASC",description:null,isDeprecated:false,deprecationReason:null},{name:"DESC",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"OBJECT",name:"PageInfo",description:null,fields:[{name:"endCursor",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"hasNextPage",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Boolean",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"hasPreviousPage",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Boolean",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"startCursor",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"Query",description:null,fields:[{name:"ethereum",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaType",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"ethereumSepolia",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaType",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"polygon",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"EVMSchemaType",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"SCALAR",name:"String",description:"The `String` scalar type represents textual data, represented as UTF-8 character sequences. The String type is most often used by GraphQL to represent free-form human-readable text.",fields:null,inputFields:null,interfaces:null,enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"StringInput",description:null,fields:null,inputFields:[{name:"eq",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"in",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"notIn",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TokenAttribute",description:"A token attribute",fields:[{name:"name",description:"Attribute name",args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"value",description:"Attribute value",args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TokenBurnEvent",description:null,fields:[{name:"blockNumber",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[],type:{kind:"INTERFACE",name:"Contract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contractERCStandard",description:null,args:[],type:{kind:"ENUM",name:"ERCStandard",ofType:null},isDeprecated:false,deprecationReason:null},{name:"from",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"fromAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"nft",description:null,args:[],type:{kind:"INTERFACE",name:"NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"timestamp",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"DateTime",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"to",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"toAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"tokenId",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenQuantity",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"transaction",description:null,args:[],type:{kind:"OBJECT",name:"Transaction",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transactionHash",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transferIndex",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"type",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"TokenTransferType",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"TokenEvent",ofType:null}],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TokenContract",description:null,fields:[{name:"abi",description:null,args:[],type:{kind:"SCALAR",name:"JSON",ofType:null},isDeprecated:false,deprecationReason:null},{name:"address",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"decimals",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"details",description:null,args:[],type:{kind:"OBJECT",name:"TokenDetailsType",ofType:null},isDeprecated:false,deprecationReason:null},{name:"isVerified",description:"Contract with verified ABI",args:[],type:{kind:"SCALAR",name:"Boolean",ofType:null},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"supportedErcInterfaces",description:null,args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"symbol",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"ContractTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"Contract",ofType:null}],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TokenDetailsType",description:null,fields:[{name:"address",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"slug",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"symbol",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"INTERFACE",name:"TokenEvent",description:null,fields:[{name:"blockNumber",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"from",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"fromAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"timestamp",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"DateTime",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"to",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"toAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"transaction",description:null,args:[],type:{kind:"OBJECT",name:"Transaction",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transactionHash",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transferIndex",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"type",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"TokenTransferType",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:[{kind:"OBJECT",name:"TokenBurnEvent",ofType:null},{kind:"OBJECT",name:"TokenMintEvent",ofType:null},{kind:"OBJECT",name:"TokenSaleEvent",ofType:null},{kind:"OBJECT",name:"TokenSwapEvent",ofType:null},{kind:"OBJECT",name:"TokenTransferEvent",ofType:null}]},{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",description:"Filter input for token events",fields:null,inputFields:[{name:"blockNumber",description:"Filter token events by their block number",type:{kind:"INPUT_OBJECT",name:"IntegerInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:"Filter token events by contract address",type:{kind:"INPUT_OBJECT",name:"StringInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"contractStandard",description:"Filter token events by their contract standard",type:{kind:"INPUT_OBJECT",name:"ContractStandardInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"fromAddress",description:"Filter token events by the \"from\" wallet",type:{kind:"INPUT_OBJECT",name:"StringInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"marketplace",description:"Filter token events by the marketplace. It's only valid for SALE types",type:{kind:"INPUT_OBJECT",name:"MarketplaceInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"timestamp",description:"Filter token events by their estimated confirmation date",type:{kind:"INPUT_OBJECT",name:"DateTimeInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"toAddress",description:"Filter token events by the \"to\" wallet",type:{kind:"INPUT_OBJECT",name:"StringInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"transactionHash",description:"Filter token events by transaction hash",type:{kind:"INPUT_OBJECT",name:"StringInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"type",description:"Filter token events by their type",type:{kind:"INPUT_OBJECT",name:"TokenTransferTypeInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"walletAddress",description:"Filter token events by the \"to\" and \"from\" wallet",type:{kind:"INPUT_OBJECT",name:"StringInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TokenMintEvent",description:null,fields:[{name:"blockNumber",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[],type:{kind:"INTERFACE",name:"Contract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contractERCStandard",description:null,args:[],type:{kind:"ENUM",name:"ERCStandard",ofType:null},isDeprecated:false,deprecationReason:null},{name:"from",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"fromAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"nft",description:null,args:[],type:{kind:"INTERFACE",name:"NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"timestamp",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"DateTime",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"to",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"toAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"tokenId",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenQuantity",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"transaction",description:null,args:[],type:{kind:"OBJECT",name:"Transaction",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transactionHash",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transferIndex",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"type",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"TokenTransferType",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"TokenEvent",ofType:null}],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TokenSaleEvent",description:null,fields:[{name:"blockNumber",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contractERCStandard",description:null,args:[],type:{kind:"ENUM",name:"ERCStandard",ofType:null},isDeprecated:false,deprecationReason:null},{name:"from",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"fromAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"marketplace",description:"Marketplace used to make the sale",args:[],type:{kind:"ENUM",name:"Marketplace",ofType:null},isDeprecated:false,deprecationReason:null},{name:"receivedNft",description:null,args:[],type:{kind:"INTERFACE",name:"NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"receivedTokenContract",description:null,args:[],type:{kind:"INTERFACE",name:"Contract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"receivedTokenContractAddress",description:"The address of the token received as payment of the sale proceeds",args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"receivedTokenId",description:"The id of the token received as payment of the sale proceeds",args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"receivedTokenQuantity",description:"The quantity of tokens received as payment of the sale proceeds",args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"sentNft",description:null,args:[],type:{kind:"INTERFACE",name:"NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"sentTokenContract",description:null,args:[],type:{kind:"INTERFACE",name:"Contract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"sentTokenId",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"sentTokenQuantity",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"timestamp",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"DateTime",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"to",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"toAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"transaction",description:null,args:[],type:{kind:"OBJECT",name:"Transaction",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transactionHash",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transferIndex",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"type",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"TokenTransferType",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"TokenEvent",ofType:null}],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TokenSwapEvent",description:null,fields:[{name:"blockNumber",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"from",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"fromAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"receivedNft",description:null,args:[],type:{kind:"INTERFACE",name:"NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"receivedTokenContract",description:null,args:[],type:{kind:"INTERFACE",name:"Contract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"receivedTokenContractAddress",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"receivedTokenId",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"receivedTokenQuantity",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"sentNft",description:null,args:[],type:{kind:"INTERFACE",name:"NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"sentTokenContract",description:null,args:[],type:{kind:"INTERFACE",name:"Contract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"sentTokenContractAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"sentTokenContractERCStandard",description:null,args:[],type:{kind:"ENUM",name:"ERCStandard",ofType:null},isDeprecated:false,deprecationReason:null},{name:"sentTokenId",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"sentTokenQuantity",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"timestamp",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"DateTime",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"to",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"toAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"transaction",description:null,args:[],type:{kind:"OBJECT",name:"Transaction",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transactionHash",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transferIndex",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"type",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"TokenTransferType",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"TokenEvent",ofType:null}],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TokenTransferEvent",description:null,fields:[{name:"blockNumber",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contract",description:null,args:[],type:{kind:"INTERFACE",name:"Contract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contractERCStandard",description:null,args:[],type:{kind:"ENUM",name:"ERCStandard",ofType:null},isDeprecated:false,deprecationReason:null},{name:"from",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"fromAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"nft",description:null,args:[],type:{kind:"INTERFACE",name:"NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"timestamp",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"DateTime",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"to",description:null,args:[],type:{kind:"OBJECT",name:"Wallet",ofType:null},isDeprecated:false,deprecationReason:null},{name:"toAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"tokenId",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"tokenQuantity",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"transaction",description:null,args:[],type:{kind:"OBJECT",name:"Transaction",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transactionHash",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transferIndex",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"type",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"TokenTransferType",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[{kind:"INTERFACE",name:"TokenEvent",ofType:null}],enumValues:null,possibleTypes:null},{kind:"ENUM",name:"TokenTransferType",description:null,fields:null,inputFields:null,interfaces:null,enumValues:[{name:"BURN",description:null,isDeprecated:false,deprecationReason:null},{name:"MINT",description:null,isDeprecated:false,deprecationReason:null},{name:"SALE",description:null,isDeprecated:false,deprecationReason:null},{name:"SWAP",description:null,isDeprecated:false,deprecationReason:null},{name:"TRANSFER",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"INPUT_OBJECT",name:"TokenTransferTypeInput",description:null,fields:null,inputFields:[{name:"eq",description:null,type:{kind:"ENUM",name:"TokenTransferType",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"in",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"TokenTransferType",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"notIn",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"TokenTransferType",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TokenUpload",description:"Token media uploads.",fields:[{name:"height",description:"The upload height.",args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"mimeType",description:"The upload mimeType.",args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"url",description:"The upload url.",args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"width",description:"The upload width.",args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"Transaction",description:null,fields:[{name:"blockNumber",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"blockTimestamp",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"DateTime",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"cumulativeGasUsed",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"effectiveGasPrice",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"fromAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"gas",description:"The amount of gas supplied for this transaction to happen",args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"gasPrice",description:"Cost in Gwei per unit of gas for this transaction",args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"gasUsed",description:"The amount of gas used by this transaction",args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"hash",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"input",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"maxFeePerGas",description:"Max gas fee in Gwei",args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"maxPriorityFeePerGas",description:"Max gas priority fee in Gwei",args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null},{name:"toAddress",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"transactionIndex",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Int",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"type",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"value",description:null,args:[],type:{kind:"SCALAR",name:"BigInt",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"TransactionsFilterInput",description:"Filter input for transactions",fields:null,inputFields:[{name:"blockNumber",description:null,type:{kind:"INPUT_OBJECT",name:"IntegerInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"fromAddress",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"timestamp",description:null,type:{kind:"INPUT_OBJECT",name:"DateTimeInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"toAddress",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TrendingCollection",description:null,fields:[{name:"collection",description:null,args:[],type:{kind:"INTERFACE",name:"Collection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"last20Sales",description:null,args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"CollectionSale",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"stats",description:null,args:[],type:{kind:"OBJECT",name:"TrendingCollectionStats",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"TrendingCollectionStats",description:"Stats of a trending collection",fields:[{name:"average",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"ceiling",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"floor",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"totalSales",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null},{name:"volume",description:null,args:[],type:{kind:"SCALAR",name:"Float",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"TrendingCollectionsFilterInput",description:"Filter input for trending collections",fields:null,inputFields:[{name:"timePeriod",description:"A time period relative to the current time in which to filter trending collections by.",type:{kind:"ENUM",name:"TrendingPeriod",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"timeRange",description:"Custom time range in which to filter trending collections by. Available only to paid customers.",type:{kind:"INPUT_OBJECT",name:"DateTimeInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"ENUM",name:"TrendingOrderBy",description:null,fields:null,inputFields:null,interfaces:null,enumValues:[{name:"AVERAGE",description:null,isDeprecated:false,deprecationReason:null},{name:"SALES",description:null,isDeprecated:false,deprecationReason:null},{name:"VOLUME",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"ENUM",name:"TrendingPeriod",description:null,fields:null,inputFields:null,interfaces:null,enumValues:[{name:"FIFTEEN_MINUTES",description:null,isDeprecated:false,deprecationReason:null},{name:"FIVE_MINUTES",description:null,isDeprecated:false,deprecationReason:null},{name:"ONE_DAY",description:null,isDeprecated:false,deprecationReason:null},{name:"ONE_HOUR",description:null,isDeprecated:false,deprecationReason:null},{name:"ONE_MINUTE",description:null,isDeprecated:false,deprecationReason:null},{name:"SEVEN_DAYS",description:null,isDeprecated:false,deprecationReason:null},{name:"THIRTY_MINUTES",description:null,isDeprecated:false,deprecationReason:null},{name:"TWELVE_HOURS",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"OBJECT",name:"Wallet",description:null,fields:[{name:"address",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"ensName",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"heldCollection",description:null,args:[{name:"collectionAddress",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"WalletCollection",ofType:null},isDeprecated:true,deprecationReason:"Use wallet.collection instead."},{name:"heldCollections",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"WalletCollectionsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderBy",description:null,type:{kind:"ENUM",name:"WalletCollectionOrderBy",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletHeldCollectionsConnection",ofType:null}},isDeprecated:true,deprecationReason:"Use wallet.collections instead."},{name:"heldNft",description:null,args:[{name:"contractAddress",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"tokenId",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"WalletNFT",ofType:null},isDeprecated:true,deprecationReason:"Use wallet.nft instead."},{name:"heldNfts",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"WalletNFTsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderBy",description:null,type:{kind:"ENUM",name:"WalletNFTsOrderBy",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletHeldNFTsConnection",ofType:null}},isDeprecated:true,deprecationReason:"Use wallet.nfts instead."},{name:"heldTokenBalances",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderBy",description:null,type:{kind:"ENUM",name:"WalletTokenBalanceOrder",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletHeldTokenBalancesConnection",ofType:null}},isDeprecated:true,deprecationReason:"Use wallet.tokenBalances instead."},{name:"tokenBalances",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderBy",description:null,type:{kind:"ENUM",name:"WalletTokenBalanceOrder",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletTokenBalancesConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"tokenEvents",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TokenEventsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletTokenEventsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"transactions",description:"Returns a list of transactions this wallet is associated with. Ordered by block number and index.",args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"TransactionsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletTransactionsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"walletCollection",description:null,args:[{name:"collectionAddress",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"WalletCollection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"walletCollections",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"WalletCollectionsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderBy",description:null,type:{kind:"ENUM",name:"WalletCollectionOrderBy",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletWalletCollectionsConnection",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"walletNFT",description:null,args:[{name:"contractAddress",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"tokenId",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"OBJECT",name:"WalletNFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"walletNFTs",description:null,args:[{name:"after",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"before",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"filter",description:null,type:{kind:"INPUT_OBJECT",name:"WalletNFTsFilterInput",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"first",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"last",description:null,type:{kind:"SCALAR",name:"Int",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderBy",description:null,type:{kind:"ENUM",name:"WalletNFTsOrderBy",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null},{name:"orderDirection",description:"The direction you want to order results: ASC/DESC. Defaults to DESC.",type:{kind:"ENUM",name:"OrderDirection",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletNFTsConnection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletCollection",description:null,fields:[{name:"collection",description:null,args:[],type:{kind:"INTERFACE",name:"Collection",ofType:null},isDeprecated:false,deprecationReason:null},{name:"collectionAddress",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"heldTokensCount",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:true,deprecationReason:"Use nftsCount instead."},{name:"nftsCount",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"ENUM",name:"WalletCollectionOrderBy",description:null,fields:null,inputFields:null,interfaces:null,enumValues:[{name:"DATE_ACQUIRED",description:null,isDeprecated:false,deprecationReason:null},{name:"NAME",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"INPUT_OBJECT",name:"WalletCollectionsFilterInput",description:"Filter of collections in a wallet",fields:null,inputFields:[{name:"contractAddressIn",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletHeldCollectionsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletHeldCollectionsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletHeldCollectionsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletCollection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletHeldNFTsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletHeldNFTsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletHeldNFTsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletNFT",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletHeldTokenBalancesConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletHeldTokenBalancesConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletHeldTokenBalancesConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletTokenBalance",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletNFT",description:null,fields:[{name:"heldNftCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:true,deprecationReason:"Use nftsCount instead."},{name:"nft",description:null,args:[],type:{kind:"INTERFACE",name:"NFT",ofType:null},isDeprecated:false,deprecationReason:null},{name:"nftsCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletNFTsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletNFTsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletNFTsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletNFT",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"INPUT_OBJECT",name:"WalletNFTsFilterInput",description:"Filter of nfts in a wallet",fields:null,inputFields:[{name:"contractAddressIn",description:null,type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}}},defaultValue:null,isDeprecated:false,deprecationReason:null}],interfaces:null,enumValues:null,possibleTypes:null},{kind:"ENUM",name:"WalletNFTsOrderBy",description:null,fields:null,inputFields:null,interfaces:null,enumValues:[{name:"DATE_ACQUIRED",description:null,isDeprecated:false,deprecationReason:null},{name:"NAME",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"OBJECT",name:"WalletTokenBalance",description:null,fields:[{name:"contract",description:null,args:[],type:{kind:"OBJECT",name:"TokenContract",ofType:null},isDeprecated:false,deprecationReason:null},{name:"contractAddress",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalBalance",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"BigInt",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"ENUM",name:"WalletTokenBalanceOrder",description:"Sort wallet token balance",fields:null,inputFields:null,interfaces:null,enumValues:[{name:"CONTRACT_ADDRESS",description:null,isDeprecated:false,deprecationReason:null},{name:"NAME",description:null,isDeprecated:false,deprecationReason:null},{name:"SYMBOL",description:null,isDeprecated:false,deprecationReason:null},{name:"TOTAL_BALANCE",description:null,isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"OBJECT",name:"WalletTokenBalancesConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletTokenBalancesConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletTokenBalancesConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletTokenBalance",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletTokenEventsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletTokenEventsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletTokenEventsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"INTERFACE",name:"TokenEvent",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletTransactionsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletTransactionsEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletTransactionsEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"Transaction",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletWalletCollectionsConnection",description:null,fields:[{name:"edges",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletWalletCollectionsConnectionEdge",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"pageInfo",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"PageInfo",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"totalCount",description:null,args:[],type:{kind:"SCALAR",name:"Int",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"WalletWalletCollectionsConnectionEdge",description:null,fields:[{name:"cursor",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"node",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"WalletCollection",ofType:null}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"__Directive",description:"A Directive provides a way to describe alternate runtime execution and type validation behavior in a GraphQL document.\n\nIn some cases, you need to provide options to alter GraphQL's execution behavior in ways field arguments will not suffice, such as conditionally including or skipping a field. Directives provide this by describing additional information to the executor.",fields:[{name:"name",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"isRepeatable",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Boolean",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"locations",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"__DirectiveLocation",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"args",description:null,args:[{name:"includeDeprecated",description:null,type:{kind:"SCALAR",name:"Boolean",ofType:null},defaultValue:"false",isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__InputValue",ofType:null}}}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"ENUM",name:"__DirectiveLocation",description:"A Directive can be adjacent to many parts of the GraphQL language, a __DirectiveLocation describes one such possible adjacencies.",fields:null,inputFields:null,interfaces:null,enumValues:[{name:"QUERY",description:"Location adjacent to a query operation.",isDeprecated:false,deprecationReason:null},{name:"MUTATION",description:"Location adjacent to a mutation operation.",isDeprecated:false,deprecationReason:null},{name:"SUBSCRIPTION",description:"Location adjacent to a subscription operation.",isDeprecated:false,deprecationReason:null},{name:"FIELD",description:"Location adjacent to a field.",isDeprecated:false,deprecationReason:null},{name:"FRAGMENT_DEFINITION",description:"Location adjacent to a fragment definition.",isDeprecated:false,deprecationReason:null},{name:"FRAGMENT_SPREAD",description:"Location adjacent to a fragment spread.",isDeprecated:false,deprecationReason:null},{name:"INLINE_FRAGMENT",description:"Location adjacent to an inline fragment.",isDeprecated:false,deprecationReason:null},{name:"VARIABLE_DEFINITION",description:"Location adjacent to a variable definition.",isDeprecated:false,deprecationReason:null},{name:"SCHEMA",description:"Location adjacent to a schema definition.",isDeprecated:false,deprecationReason:null},{name:"SCALAR",description:"Location adjacent to a scalar definition.",isDeprecated:false,deprecationReason:null},{name:"OBJECT",description:"Location adjacent to an object type definition.",isDeprecated:false,deprecationReason:null},{name:"FIELD_DEFINITION",description:"Location adjacent to a field definition.",isDeprecated:false,deprecationReason:null},{name:"ARGUMENT_DEFINITION",description:"Location adjacent to an argument definition.",isDeprecated:false,deprecationReason:null},{name:"INTERFACE",description:"Location adjacent to an interface definition.",isDeprecated:false,deprecationReason:null},{name:"UNION",description:"Location adjacent to a union definition.",isDeprecated:false,deprecationReason:null},{name:"ENUM",description:"Location adjacent to an enum definition.",isDeprecated:false,deprecationReason:null},{name:"ENUM_VALUE",description:"Location adjacent to an enum value definition.",isDeprecated:false,deprecationReason:null},{name:"INPUT_OBJECT",description:"Location adjacent to an input object type definition.",isDeprecated:false,deprecationReason:null},{name:"INPUT_FIELD_DEFINITION",description:"Location adjacent to an input object field definition.",isDeprecated:false,deprecationReason:null}],possibleTypes:null},{kind:"OBJECT",name:"__EnumValue",description:"One possible value for a given Enum. Enum values are unique values, not a placeholder for a string or numeric value. However an Enum value is returned in a JSON response as a string.",fields:[{name:"name",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"isDeprecated",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Boolean",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"deprecationReason",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"__Field",description:"Object and Interface types are described by a list of Fields, each of which has a name, potentially a list of arguments, and a return type.",fields:[{name:"name",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"args",description:null,args:[{name:"includeDeprecated",description:null,type:{kind:"SCALAR",name:"Boolean",ofType:null},defaultValue:"false",isDeprecated:false,deprecationReason:null}],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__InputValue",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"type",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__Type",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"isDeprecated",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Boolean",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"deprecationReason",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"__InputValue",description:"Arguments provided to Fields or Directives and the input fields of an InputObject are represented as Input Values which describe their type and optionally a default value.",fields:[{name:"name",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"type",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__Type",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"defaultValue",description:"A GraphQL-formatted string representing the default value for this input value.",args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"isDeprecated",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Boolean",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"deprecationReason",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"__Schema",description:"A GraphQL Schema defines the capabilities of a GraphQL server. It exposes all available types and directives on the server, as well as the entry points for query, mutation, and subscription operations.",fields:[{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"types",description:"A list of all types supported by this server.",args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__Type",ofType:null}}}},isDeprecated:false,deprecationReason:null},{name:"queryType",description:"The type that query operations will be rooted at.",args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__Type",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"mutationType",description:"If this server supports mutation, the type that mutation operations will be rooted at.",args:[],type:{kind:"OBJECT",name:"__Type",ofType:null},isDeprecated:false,deprecationReason:null},{name:"subscriptionType",description:"If this server support subscription, the type that subscription operations will be rooted at.",args:[],type:{kind:"OBJECT",name:"__Type",ofType:null},isDeprecated:false,deprecationReason:null},{name:"directives",description:"A list of all directives supported by this server.",args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__Directive",ofType:null}}}},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"OBJECT",name:"__Type",description:"The fundamental unit of any GraphQL Schema is the type. There are many kinds of types in GraphQL as represented by the `__TypeKind` enum.\n\nDepending on the kind of a type, certain fields describe information about that type. Scalar types provide no information beyond a name, description and optional `specifiedByURL`, while Enum types provide their values. Object and Interface types provide the fields they describe. Abstract types, Union and Interface, provide the Object types possible at runtime. List and NonNull types compose other types.",fields:[{name:"kind",description:null,args:[],type:{kind:"NON_NULL",name:null,ofType:{kind:"ENUM",name:"__TypeKind",ofType:null}},isDeprecated:false,deprecationReason:null},{name:"name",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"description",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"specifiedByURL",description:null,args:[],type:{kind:"SCALAR",name:"String",ofType:null},isDeprecated:false,deprecationReason:null},{name:"fields",description:null,args:[{name:"includeDeprecated",description:null,type:{kind:"SCALAR",name:"Boolean",ofType:null},defaultValue:"false",isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__Field",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"interfaces",description:null,args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__Type",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"possibleTypes",description:null,args:[],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__Type",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"enumValues",description:null,args:[{name:"includeDeprecated",description:null,type:{kind:"SCALAR",name:"Boolean",ofType:null},defaultValue:"false",isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__EnumValue",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"inputFields",description:null,args:[{name:"includeDeprecated",description:null,type:{kind:"SCALAR",name:"Boolean",ofType:null},defaultValue:"false",isDeprecated:false,deprecationReason:null}],type:{kind:"LIST",name:null,ofType:{kind:"NON_NULL",name:null,ofType:{kind:"OBJECT",name:"__InputValue",ofType:null}}},isDeprecated:false,deprecationReason:null},{name:"ofType",description:null,args:[],type:{kind:"OBJECT",name:"__Type",ofType:null},isDeprecated:false,deprecationReason:null}],inputFields:null,interfaces:[],enumValues:null,possibleTypes:null},{kind:"ENUM",name:"__TypeKind",description:"An enum describing what kind of type a given `__Type` is.",fields:null,inputFields:null,interfaces:null,enumValues:[{name:"SCALAR",description:"Indicates this type is a scalar.",isDeprecated:false,deprecationReason:null},{name:"OBJECT",description:"Indicates this type is an object. `fields` and `interfaces` are valid fields.",isDeprecated:false,deprecationReason:null},{name:"INTERFACE",description:"Indicates this type is an interface. `fields`, `interfaces`, and `possibleTypes` are valid fields.",isDeprecated:false,deprecationReason:null},{name:"UNION",description:"Indicates this type is a union. `possibleTypes` is a valid field.",isDeprecated:false,deprecationReason:null},{name:"ENUM",description:"Indicates this type is an enum. `enumValues` is a valid field.",isDeprecated:false,deprecationReason:null},{name:"INPUT_OBJECT",description:"Indicates this type is an input object. `inputFields` is a valid field.",isDeprecated:false,deprecationReason:null},{name:"LIST",description:"Indicates this type is a list. `ofType` is a valid field.",isDeprecated:false,deprecationReason:null},{name:"NON_NULL",description:"Indicates this type is a non-null. `ofType` is a valid field.",isDeprecated:false,deprecationReason:null}],possibleTypes:null}],directives:[{name:"defer",description:null,isRepeatable:false,locations:["FRAGMENT_SPREAD","INLINE_FRAGMENT"],args:[{name:"if",description:null,type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Boolean",ofType:null}},defaultValue:"true",isDeprecated:false,deprecationReason:null},{name:"label",description:null,type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:null,isDeprecated:false,deprecationReason:null}]},{name:"deprecated",description:"Marks an element of a GraphQL schema as no longer supported.",isRepeatable:false,locations:["ARGUMENT_DEFINITION","ENUM_VALUE","FIELD_DEFINITION","INPUT_FIELD_DEFINITION"],args:[{name:"reason",description:"Explains why this element was deprecated, usually also including a suggestion for how to access supported similar data. Formatted using the Markdown syntax, as specified by [CommonMark](https://commonmark.org/).",type:{kind:"SCALAR",name:"String",ofType:null},defaultValue:"\"No longer supported\"",isDeprecated:false,deprecationReason:null}]},{name:"include",description:"Directs the executor to include this field or fragment only when the `if` argument is true.",isRepeatable:false,locations:["FIELD","FRAGMENT_SPREAD","INLINE_FRAGMENT"],args:[{name:"if",description:"Included when true.",type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Boolean",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}]},{name:"skip",description:"Directs the executor to skip this field or fragment when the `if` argument is true.",isRepeatable:false,locations:["FIELD","FRAGMENT_SPREAD","INLINE_FRAGMENT"],args:[{name:"if",description:"Skipped when true.",type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"Boolean",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}]},{name:"specifiedBy",description:"Exposes a URL that specifies the behavior of this scalar.",isRepeatable:false,locations:["SCALAR"],args:[{name:"url",description:"The URL that specifies the behavior of this scalar.",type:{kind:"NON_NULL",name:null,ofType:{kind:"SCALAR",name:"String",ofType:null}},defaultValue:null,isDeprecated:false,deprecationReason:null}]}]};var schema = {__schema:__schema};

class TransactionsController {
    constructor(client, defaultChain = DEFAULT_CHAIN) {
        this.client = client;
        this.defaultChain = defaultChain;
    }
    async getByWallet(variables) {
        const { address, ...allVariables } = variables;
        let queryResult;
        if (isValidENSAddress(address)) {
            queryResult = await this.getByWalletENS({
                ensName: address,
                ...allVariables,
            });
        }
        else {
            queryResult = await this.getByWalletAddress({
                address,
                ...allVariables,
            });
        }
        if (!queryResult?.transactions?.length) {
            // Address can still be valid address, but not have any transactions
            const address = queryResult?.address || '';
            const ensName = queryResult?.ensName || '';
            return {
                address: address,
                ensName: ensName,
                results: [],
                pageInfo: emptyPageInfo,
            };
        }
        const formattedResult = formatQueryResult(queryResult, 'transactions', 'transactionsPageInfo');
        return formattedResult;
    }
    async getByWalletAddress(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetTransactionsByWalletAddressDocument,
            polygon: CodegenPolygonMainnetTransactionsByWalletAddressDocument,
            ethereumSepolia: CodegenEthSepoliaTransactionsByWalletAddressDocument,
        };
        const { data: { [userChain]: { walletByAddress }, }, } = await this.client.query({
            variables: queryVariables,
            query: query[userChain],
        });
        return walletByAddress;
    }
    async getByWalletENS(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetTransactionsByWalletENSDocument,
            polygon: CodegenPolygonMainnetTransactionsByWalletENSDocument,
            ethereumSepolia: CodegenEthSepoliaTransactionsByWalletENSDocument,
        };
        const { data: { [userChain]: { walletByENS }, }, } = await this.client.query({
            variables: queryVariables,
            query: query[userChain],
        });
        return walletByENS;
    }
    async getAll(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetTransactionsBySearchDocument,
            polygon: CodegenPolygonMainnetTransactionsBySearchDocument,
            ethereumSepolia: CodegenEthSepoliaTransactionsBySearchDocument,
        };
        const { data: { [userChain]: transactions }, } = await this.client.query({
            variables: queryVariables,
            query: query[userChain],
        });
        const formattedResult = formatQueryResult(transactions, 'transactions', 'transactionsPageInfo');
        return formattedResult;
    }
    async getByHash(variables) {
        const { chain, ...queryVariables } = variables;
        const userChain = chain || this.defaultChain;
        const query = {
            ethereum: CodegenEthMainnetTransactionsByHashDocument,
            polygon: CodegenPolygonMainnetTransactionsByHashDocument,
            ethereumSepolia: CodegenEthSepoliaTransactionsByHashDocument,
        };
        const { data: { [userChain]: transaction }, } = await this.client.query({
            variables: queryVariables,
            query: query[userChain],
        });
        if (transaction?.transaction)
            return transaction;
        return { transaction: null };
    }
}

class API {
    constructor({ graphApiKey, additionalHeaders, defaultChain, } = {}) {
        if (!graphApiKey) {
            console.warn('QuickNode SDK warning: no apiKey provided. Access with no apiKey is heavily rate limited and intended for development use only. For higher rate limits or production usage, create an account on https://www.quicknode.com/');
        }
        this.graphApiKey = graphApiKey;
        this.additionalHeaders = additionalHeaders;
        this.urqlClient = this.createUrqlClient();
        this.customUrqlClient = new CustomUrqlClient(this.urqlClient);
        this.defaultChain = defaultChain || DEFAULT_CHAIN;
        this.nfts = new NftsController(this.customUrqlClient, this.defaultChain);
        this.tokens = new TokensController(this.customUrqlClient, this.defaultChain);
        this.utils = new UtilsController(this.customUrqlClient, this.defaultChain);
        this.contracts = new ContractsController(this.customUrqlClient, this.defaultChain);
        this.transactions = new TransactionsController(this.customUrqlClient, this.defaultChain);
        this.events = new EventsController(this.customUrqlClient, this.defaultChain);
        // Re-export the Urql client configured to use the Graph API for use with custom queries
        this.graphApiClient = this.urqlClient;
    }
    createUrqlClient() {
        const headers = { ...this.additionalHeaders };
        if (this.graphApiKey)
            headers['x-api-key'] = this.graphApiKey;
        const useNftKey = (data) => `${data['contractAddress']}:${data['tokenId']}`;
        const useAddressAsKey = (data) => `${data['address']}`;
        const useTransactionHashAndIndex = (data) => `${data['transactionHash']}:${data['transferIndex']}`;
        const urqlCache = exchangeGraphcache.cacheExchange({
            schema,
            keys: {
                EVMSchemaType: () => null,
                Collection: useAddressAsKey,
                CollectionOHLCVChart: () => null,
                Contract: useAddressAsKey,
                ERC721NFT: useNftKey,
                ERC721Collection: useAddressAsKey,
                ERC1155NFT: useNftKey,
                ERC1155Collection: useAddressAsKey,
                GasPrice: () => null,
                NFT: useNftKey,
                NFTContract: useAddressAsKey,
                TokenAttribute: () => null,
                TokenContract: useAddressAsKey,
                TokenEvent: useTransactionHashAndIndex,
                TokenMintEvent: useTransactionHashAndIndex,
                TokenBurnEvent: useTransactionHashAndIndex,
                TokenSaleEvent: useTransactionHashAndIndex,
                TokenSwapEvent: useTransactionHashAndIndex,
                TokenTransferEvent: useTransactionHashAndIndex,
                TokenUpload: () => null,
                OpenSeaMetadata: () => null,
                Transaction: (data) => `${data['hash']}`,
                TrendingCollection: () => null,
                Wallet: (data) => `${data['address']}`,
                WalletNFT: () => null,
                WalletTokenBalance: () => null,
            },
        });
        const client = new core.Client({
            fetch: fetch__default["default"],
            url: process.env['NX_GRAPHQL_API_URI'] ||
                'https://api.quicknode.com/graphql',
            exchanges: [urqlCache, core.fetchExchange],
            fetchOptions: () => ({ headers }),
        });
        return client;
    }
}

const QuickNode = {
    API: API,
};

Object.defineProperty(exports, 'gql', {
    enumerable: true,
    get: function () { return core.gql; }
});
exports.API = API;
exports["default"] = QuickNode;
